# Copyright (c) 2023 Darren Erik Vengroff
"""Metropolitan Statistical Area Micropolitan Statistical Areas."""


ABERDEEN_SD_MICRO_AREA = "10100"
ABERDEEN_WA_MICRO_AREA = "10140"
ABILENE_TX_METRO_AREA = "10180"
ADA_OK_MICRO_AREA = "10220"
ADRIAN_MI_MICRO_AREA = "10300"
AGUADILLA_ISABELA_PR_METRO_AREA = "10380"
AKRON_OH_METRO_AREA = "10420"
ALAMOGORDO_NM_MICRO_AREA = "10460"
ALBANY_GA_METRO_AREA = "10500"
ALBANY_LEBANON_OR_METRO_AREA = "10540"
ALBANY_SCHENECTADY_TROY_NY_METRO_AREA = "10580"
ALBEMARLE_NC_MICRO_AREA = "10620"
ALBERT_LEA_MN_MICRO_AREA = "10660"
ALBERTVILLE_AL_MICRO_AREA = "10700"
ALBUQUERQUE_NM_METRO_AREA = "10740"
ALEXANDER_CITY_AL_MICRO_AREA = "10760"
ALEXANDRIA_LA_METRO_AREA = "10780"
ALEXANDRIA_MN_MICRO_AREA = "10820"
ALICE_TX_MICRO_AREA = "10860"
ALLENTOWN_BETHLEHEM_EASTON_PA_NJ_METRO_AREA = "10900"
ALMA_MI_MICRO_AREA = "10940"
ALPENA_MI_MICRO_AREA = "10980"
ALTOONA_PA_METRO_AREA = "11020"
ALTUS_OK_MICRO_AREA = "11060"
AMARILLO_TX_METRO_AREA = "11100"
AMERICUS_GA_MICRO_AREA = "11140"
AMES_IA_METRO_AREA = "11180"
AMSTERDAM_NY_MICRO_AREA = "11220"
ANCHORAGE_AK_METRO_AREA = "11260"
ANDREWS_TX_MICRO_AREA = "11380"
ANGOLA_IN_MICRO_AREA = "11420"
ANN_ARBOR_MI_METRO_AREA = "11460"
ANNISTON_OXFORD_AL_METRO_AREA = "11500"
APPLETON_WI_METRO_AREA = "11540"
ARCADIA_FL_MICRO_AREA = "11580"
ARDMORE_OK_MICRO_AREA = "11620"
ARECIBO_PR_METRO_AREA = "11640"
ARKADELPHIA_AR_MICRO_AREA = "11660"
ASHEVILLE_NC_METRO_AREA = "11700"
ASHLAND_OH_MICRO_AREA = "11740"
ASHTABULA_OH_MICRO_AREA = "11780"
ASTORIA_OR_MICRO_AREA = "11820"
ATCHISON_KS_MICRO_AREA = "11860"
ATHENS_OH_MICRO_AREA = "11900"
ATHENS_TN_MICRO_AREA = "11940"
ATHENS_TX_MICRO_AREA = "11980"
ATHENS_CLARKE_COUNTY_GA_METRO_AREA = "12020"
ATLANTA_SANDY_SPRINGS_ALPHARETTA_GA_METRO_AREA = "12060"
ATLANTIC_CITY_HAMMONTON_NJ_METRO_AREA = "12100"
ATMORE_AL_MICRO_AREA = "12120"
AUBURN_IN_MICRO_AREA = "12140"
AUBURN_NY_MICRO_AREA = "12180"
AUBURN_OPELIKA_AL_METRO_AREA = "12220"
AUGUSTA_RICHMOND_COUNTY_GA_SC_METRO_AREA = "12260"
AUGUSTA_WATERVILLE_ME_MICRO_AREA = "12300"
AUSTIN_MN_MICRO_AREA = "12380"
AUSTIN_ROUND_ROCK_GEORGETOWN_TX_METRO_AREA = "12420"
BAINBRIDGE_GA_MICRO_AREA = "12460"
BAKERSFIELD_CA_METRO_AREA = "12540"
BALTIMORE_COLUMBIA_TOWSON_MD_METRO_AREA = "12580"
BANGOR_ME_METRO_AREA = "12620"
BARABOO_WI_MICRO_AREA = "12660"
BARDSTOWN_KY_MICRO_AREA = "12680"
BARNSTABLE_TOWN_MA_METRO_AREA = "12700"
BARRE_VT_MICRO_AREA = "12740"
BARTLESVILLE_OK_MICRO_AREA = "12780"
BATAVIA_NY_MICRO_AREA = "12860"
BATESVILLE_AR_MICRO_AREA = "12900"
BATON_ROUGE_LA_METRO_AREA = "12940"
BATTLE_CREEK_MI_METRO_AREA = "12980"
BAY_CITY_MI_METRO_AREA = "13020"
BAY_CITY_TX_MICRO_AREA = "13060"
BEATRICE_NE_MICRO_AREA = "13100"
BEAUMONT_PORT_ARTHUR_TX_METRO_AREA = "13140"
BEAVER_DAM_WI_MICRO_AREA = "13180"
BECKLEY_WV_METRO_AREA = "13220"
BEDFORD_IN_MICRO_AREA = "13260"
BEEVILLE_TX_MICRO_AREA = "13300"
BELLEFONTAINE_OH_MICRO_AREA = "13340"
BELLINGHAM_WA_METRO_AREA = "13380"
BEMIDJI_MN_MICRO_AREA = "13420"
BEND_OR_METRO_AREA = "13460"
BENNETTSVILLE_SC_MICRO_AREA = "13500"
BENNINGTON_VT_MICRO_AREA = "13540"
BERLIN_NH_MICRO_AREA = "13620"
BIG_RAPIDS_MI_MICRO_AREA = "13660"
BIG_SPRING_TX_MICRO_AREA = "13700"
BIG_STONE_GAP_VA_MICRO_AREA = "13720"
BILLINGS_MT_METRO_AREA = "13740"
BINGHAMTON_NY_METRO_AREA = "13780"
BIRMINGHAM_HOOVER_AL_METRO_AREA = "13820"
BISMARCK_ND_METRO_AREA = "13900"
BLACKFOOT_ID_MICRO_AREA = "13940"
BLACKSBURG_CHRISTIANSBURG_VA_METRO_AREA = "13980"
BLOOMINGTON_IL_METRO_AREA = "14010"
BLOOMINGTON_IN_METRO_AREA = "14020"
BLOOMSBURG_BERWICK_PA_METRO_AREA = "14100"
BLUEFIELD_WV_VA_MICRO_AREA = "14140"
BLUFFTON_IN_MICRO_AREA = "14160"
BLYTHEVILLE_AR_MICRO_AREA = "14180"
BOGALUSA_LA_MICRO_AREA = "14220"
BOISE_CITY_ID_METRO_AREA = "14260"
BONHAM_TX_MICRO_AREA = "14300"
BOONE_NC_MICRO_AREA = "14380"
BORGER_TX_MICRO_AREA = "14420"
BOSTON_CAMBRIDGE_NEWTON_MA_NH_METRO_AREA = "14460"
BOULDER_CO_METRO_AREA = "14500"
BOWLING_GREEN_KY_METRO_AREA = "14540"
BOZEMAN_MT_MICRO_AREA = "14580"
BRADFORD_PA_MICRO_AREA = "14620"
BRAINERD_MN_MICRO_AREA = "14660"
BRANSON_MO_MICRO_AREA = "14700"
BRECKENRIDGE_CO_MICRO_AREA = "14720"
BREMERTON_SILVERDALE_PORT_ORCHARD_WA_METRO_AREA = "14740"
BRENHAM_TX_MICRO_AREA = "14780"
BREVARD_NC_MICRO_AREA = "14820"
BRIDGEPORT_STAMFORD_NORWALK_CT_METRO_AREA = "14860"
BROOKHAVEN_MS_MICRO_AREA = "15020"
BROOKINGS_OR_MICRO_AREA = "15060"
BROOKINGS_SD_MICRO_AREA = "15100"
BROWNSVILLE_TN_MICRO_AREA = "15140"
BROWNSVILLE_HARLINGEN_TX_METRO_AREA = "15180"
BROWNWOOD_TX_MICRO_AREA = "15220"
BRUNSWICK_GA_METRO_AREA = "15260"
BUCYRUS_GALION_OH_MICRO_AREA = "15340"
BUFFALO_CHEEKTOWAGA_NY_METRO_AREA = "15380"
BURLEY_ID_MICRO_AREA = "15420"
BURLINGTON_IA_IL_MICRO_AREA = "15460"
BURLINGTON_NC_METRO_AREA = "15500"
BURLINGTON_SOUTH_BURLINGTON_VT_METRO_AREA = "15540"
BUTTE_SILVER_BOW_MT_MICRO_AREA = "15580"
CADILLAC_MI_MICRO_AREA = "15620"
CALHOUN_GA_MICRO_AREA = "15660"
CALIFORNIA_LEXINGTON_PARK_MD_METRO_AREA = "15680"
CAMBRIDGE_MD_MICRO_AREA = "15700"
CAMBRIDGE_OH_MICRO_AREA = "15740"
CAMDEN_AR_MICRO_AREA = "15780"
CAMPBELLSVILLE_KY_MICRO_AREA = "15820"
CANTON_MASSILLON_OH_METRO_AREA = "15940"
CAPE_CORAL_FORT_MYERS_FL_METRO_AREA = "15980"
CAPE_GIRARDEAU_MO_IL_METRO_AREA = "16020"
CARBONDALE_MARION_IL_METRO_AREA = "16060"
CARLSBAD_ARTESIA_NM_MICRO_AREA = "16100"
CARROLL_IA_MICRO_AREA = "16140"
CARSON_CITY_NV_METRO_AREA = "16180"
CASPER_WY_METRO_AREA = "16220"
CANON_CITY_CO_MICRO_AREA = "15860"
CEDAR_CITY_UT_MICRO_AREA = "16260"
CEDAR_RAPIDS_IA_METRO_AREA = "16300"
CEDARTOWN_GA_MICRO_AREA = "16340"
CELINA_OH_MICRO_AREA = "16380"
CENTRAL_CITY_KY_MICRO_AREA = "16420"
CENTRALIA_IL_MICRO_AREA = "16460"
CENTRALIA_WA_MICRO_AREA = "16500"
CHAMBERSBURG_WAYNESBORO_PA_METRO_AREA = "16540"
CHAMPAIGN_URBANA_IL_METRO_AREA = "16580"
CHARLESTON_WV_METRO_AREA = "16620"
CHARLESTON_MATTOON_IL_MICRO_AREA = "16660"
CHARLESTON_NORTH_CHARLESTON_SC_METRO_AREA = "16700"
CHARLOTTE_CONCORD_GASTONIA_NC_SC_METRO_AREA = "16740"
CHARLOTTESVILLE_VA_METRO_AREA = "16820"
CHATTANOOGA_TN_GA_METRO_AREA = "16860"
CHEYENNE_WY_METRO_AREA = "16940"
CHICAGO_NAPERVILLE_ELGIN_IL_IN_WI_METRO_AREA = "16980"
CHICO_CA_METRO_AREA = "17020"
CHILLICOTHE_OH_MICRO_AREA = "17060"
CINCINNATI_OH_KY_IN_METRO_AREA = "17140"
CLARKSBURG_WV_MICRO_AREA = "17220"
CLARKSDALE_MS_MICRO_AREA = "17260"
CLARKSVILLE_TN_KY_METRO_AREA = "17300"
CLEARLAKE_CA_MICRO_AREA = "17340"
CLEVELAND_MS_MICRO_AREA = "17380"
CLEVELAND_TN_METRO_AREA = "17420"
CLEVELAND_ELYRIA_OH_METRO_AREA = "17460"
CLEWISTON_FL_MICRO_AREA = "17500"
CLINTON_IA_MICRO_AREA = "17540"
CLOVIS_NM_MICRO_AREA = "17580"
COAMO_PR_MICRO_AREA = "17620"
COCO_PR_MICRO_AREA = "17640"
COEUR_DALENE_ID_METRO_AREA = "17660"
COFFEYVILLE_KS_MICRO_AREA = "17700"
COLDWATER_MI_MICRO_AREA = "17740"
COLLEGE_STATION_BRYAN_TX_METRO_AREA = "17780"
COLORADO_SPRINGS_CO_METRO_AREA = "17820"
COLUMBIA_MO_METRO_AREA = "17860"
COLUMBIA_SC_METRO_AREA = "17900"
COLUMBUS_GA_AL_METRO_AREA = "17980"
COLUMBUS_IN_METRO_AREA = "18020"
COLUMBUS_MS_MICRO_AREA = "18060"
COLUMBUS_NE_MICRO_AREA = "18100"
COLUMBUS_OH_METRO_AREA = "18140"
CONCORD_NH_MICRO_AREA = "18180"
CONNERSVILLE_IN_MICRO_AREA = "18220"
COOKEVILLE_TN_MICRO_AREA = "18260"
COOS_BAY_OR_MICRO_AREA = "18300"
CORDELE_GA_MICRO_AREA = "18380"
CORINTH_MS_MICRO_AREA = "18420"
CORNELIA_GA_MICRO_AREA = "18460"
CORNING_NY_MICRO_AREA = "18500"
CORPUS_CHRISTI_TX_METRO_AREA = "18580"
CORSICANA_TX_MICRO_AREA = "18620"
CORTLAND_NY_MICRO_AREA = "18660"
CORVALLIS_OR_METRO_AREA = "18700"
COSHOCTON_OH_MICRO_AREA = "18740"
CRAIG_CO_MICRO_AREA = "18780"
CRAWFORDSVILLE_IN_MICRO_AREA = "18820"
CRESCENT_CITY_CA_MICRO_AREA = "18860"
CRESTVIEW_FORT_WALTON_BEACH_DESTIN_FL_METRO_AREA = "18880"
CROSSVILLE_TN_MICRO_AREA = "18900"
CULLMAN_AL_MICRO_AREA = "18980"
CULLOWHEE_NC_MICRO_AREA = "19000"
CUMBERLAND_MD_WV_METRO_AREA = "19060"
DALLAS_FORT_WORTH_ARLINGTON_TX_METRO_AREA = "19100"
DALTON_GA_METRO_AREA = "19140"
DANVILLE_IL_METRO_AREA = "19180"
DANVILLE_KY_MICRO_AREA = "19220"
DANVILLE_VA_MICRO_AREA = "19260"
DAPHNE_FAIRHOPE_FOLEY_AL_METRO_AREA = "19300"
DAVENPORT_MOLINE_ROCK_ISLAND_IA_IL_METRO_AREA = "19340"
DAYTON_TN_MICRO_AREA = "19420"
DAYTON_KETTERING_OH_METRO_AREA = "19430"
DERIDDER_LA_MICRO_AREA = "19760"
DECATUR_AL_METRO_AREA = "19460"
DECATUR_IL_METRO_AREA = "19500"
DECATUR_IN_MICRO_AREA = "19540"
DEFIANCE_OH_MICRO_AREA = "19580"
DEL_RIO_TX_MICRO_AREA = "19620"
DELTONA_DAYTONA_BEACH_ORMOND_BEACH_FL_METRO_AREA = "19660"
DEMING_NM_MICRO_AREA = "19700"
DENVER_AURORA_LAKEWOOD_CO_METRO_AREA = "19740"
DES_MOINES_WEST_DES_MOINES_IA_METRO_AREA = "19780"
DETROIT_WARREN_DEARBORN_MI_METRO_AREA = "19820"
DICKINSON_ND_MICRO_AREA = "19860"
DIXON_IL_MICRO_AREA = "19940"
DODGE_CITY_KS_MICRO_AREA = "19980"
DOTHAN_AL_METRO_AREA = "20020"
DOUGLAS_GA_MICRO_AREA = "20060"
DOVER_DE_METRO_AREA = "20100"
DUBOIS_PA_MICRO_AREA = "20180"
DUBLIN_GA_MICRO_AREA = "20140"
DUBUQUE_IA_METRO_AREA = "20220"
DULUTH_MN_WI_METRO_AREA = "20260"
DUMAS_TX_MICRO_AREA = "20300"
DUNCAN_OK_MICRO_AREA = "20340"
DURANGO_CO_MICRO_AREA = "20420"
DURANT_OK_MICRO_AREA = "20460"
DURHAM_CHAPEL_HILL_NC_METRO_AREA = "20500"
DYERSBURG_TN_MICRO_AREA = "20540"
EAGLE_PASS_TX_MICRO_AREA = "20580"
EAST_STROUDSBURG_PA_METRO_AREA = "20700"
EASTON_MD_MICRO_AREA = "20660"
EAU_CLAIRE_WI_METRO_AREA = "20740"
EDWARDS_CO_MICRO_AREA = "20780"
EFFINGHAM_IL_MICRO_AREA = "20820"
EL_CAMPO_TX_MICRO_AREA = "20900"
EL_CENTRO_CA_METRO_AREA = "20940"
EL_DORADO_AR_MICRO_AREA = "20980"
EL_PASO_TX_METRO_AREA = "21340"
ELIZABETH_CITY_NC_MICRO_AREA = "21020"
ELIZABETHTOWN_FORT_KNOX_KY_METRO_AREA = "21060"
ELK_CITY_OK_MICRO_AREA = "21120"
ELKHART_GOSHEN_IN_METRO_AREA = "21140"
ELKINS_WV_MICRO_AREA = "21180"
ELKO_NV_MICRO_AREA = "21220"
ELLENSBURG_WA_MICRO_AREA = "21260"
ELMIRA_NY_METRO_AREA = "21300"
EMPORIA_KS_MICRO_AREA = "21380"
ENID_OK_METRO_AREA = "21420"
ENTERPRISE_AL_MICRO_AREA = "21460"
ERIE_PA_METRO_AREA = "21500"
ESCANABA_MI_MICRO_AREA = "21540"
ESPANOLA_NM_MICRO_AREA = "21580"
EUFAULA_AL_GA_MICRO_AREA = "21640"
EUGENE_SPRINGFIELD_OR_METRO_AREA = "21660"
EUREKA_ARCATA_CA_MICRO_AREA = "21700"
EVANSTON_WY_MICRO_AREA = "21740"
EVANSVILLE_IN_KY_METRO_AREA = "21780"
FAIRBANKS_AK_METRO_AREA = "21820"
FAIRFIELD_IA_MICRO_AREA = "21840"
FAIRMONT_MN_MICRO_AREA = "21860"
FAIRMONT_WV_MICRO_AREA = "21900"
FALLON_NV_MICRO_AREA = "21980"
FARGO_ND_MN_METRO_AREA = "22020"
FARIBAULT_NORTHFIELD_MN_MICRO_AREA = "22060"
FARMINGTON_MO_MICRO_AREA = "22100"
FARMINGTON_NM_METRO_AREA = "22140"
FAYETTEVILLE_NC_METRO_AREA = "22180"
FAYETTEVILLE_SPRINGDALE_ROGERS_AR_METRO_AREA = "22220"
FERGUS_FALLS_MN_MICRO_AREA = "22260"
FERNLEY_NV_MICRO_AREA = "22280"
FINDLAY_OH_MICRO_AREA = "22300"
FITZGERALD_GA_MICRO_AREA = "22340"
FLAGSTAFF_AZ_METRO_AREA = "22380"
FLINT_MI_METRO_AREA = "22420"
FLORENCE_SC_METRO_AREA = "22500"
FLORENCE_MUSCLE_SHOALS_AL_METRO_AREA = "22520"
FOND_DU_LAC_WI_METRO_AREA = "22540"
FOREST_CITY_NC_MICRO_AREA = "22580"
FORREST_CITY_AR_MICRO_AREA = "22620"
FORT_COLLINS_CO_METRO_AREA = "22660"
FORT_DODGE_IA_MICRO_AREA = "22700"
FORT_LEONARD_WOOD_MO_MICRO_AREA = "22780"
FORT_MADISON_KEOKUK_IA_IL_MO_MICRO_AREA = "22800"
FORT_MORGAN_CO_MICRO_AREA = "22820"
FORT_PAYNE_AL_MICRO_AREA = "22840"
FORT_POLK_SOUTH_LA_MICRO_AREA = "22860"
FORT_SMITH_AR_OK_METRO_AREA = "22900"
FORT_WAYNE_IN_METRO_AREA = "23060"
FRANKFORT_IN_MICRO_AREA = "23140"
FRANKFORT_KY_MICRO_AREA = "23180"
FREDERICKSBURG_TX_MICRO_AREA = "23240"
FREEPORT_IL_MICRO_AREA = "23300"
FREMONT_NE_MICRO_AREA = "23340"
FREMONT_OH_MICRO_AREA = "23380"
FRESNO_CA_METRO_AREA = "23420"
GADSDEN_AL_METRO_AREA = "23460"
GAFFNEY_SC_MICRO_AREA = "23500"
GAINESVILLE_FL_METRO_AREA = "23540"
GAINESVILLE_GA_METRO_AREA = "23580"
GAINESVILLE_TX_MICRO_AREA = "23620"
GALESBURG_IL_MICRO_AREA = "23660"
GALLUP_NM_MICRO_AREA = "23700"
GARDEN_CITY_KS_MICRO_AREA = "23780"
GARDNERVILLE_RANCHOS_NV_MICRO_AREA = "23820"
GEORGETOWN_SC_MICRO_AREA = "23860"
GETTYSBURG_PA_METRO_AREA = "23900"
GILLETTE_WY_MICRO_AREA = "23940"
GLASGOW_KY_MICRO_AREA = "23980"
GLENS_FALLS_NY_METRO_AREA = "24020"
GLENWOOD_SPRINGS_CO_MICRO_AREA = "24060"
GLOVERSVILLE_NY_MICRO_AREA = "24100"
GOLDSBORO_NC_METRO_AREA = "24140"
GRANBURY_TX_MICRO_AREA = "24180"
GRAND_FORKS_ND_MN_METRO_AREA = "24220"
GRAND_ISLAND_NE_METRO_AREA = "24260"
GRAND_JUNCTION_CO_METRO_AREA = "24300"
GRAND_RAPIDS_MN_MICRO_AREA = "24330"
GRAND_RAPIDS_KENTWOOD_MI_METRO_AREA = "24340"
GRANTS_PASS_OR_METRO_AREA = "24420"
GRANTS_NM_MICRO_AREA = "24380"
GREAT_BEND_KS_MICRO_AREA = "24460"
GREAT_FALLS_MT_METRO_AREA = "24500"
GREELEY_CO_METRO_AREA = "24540"
GREEN_BAY_WI_METRO_AREA = "24580"
GREENEVILLE_TN_MICRO_AREA = "24620"
GREENSBORO_HIGH_POINT_NC_METRO_AREA = "24660"
GREENSBURG_IN_MICRO_AREA = "24700"
GREENVILLE_MS_MICRO_AREA = "24740"
GREENVILLE_NC_METRO_AREA = "24780"
GREENVILLE_OH_MICRO_AREA = "24820"
GREENVILLE_ANDERSON_SC_METRO_AREA = "24860"
GREENWOOD_MS_MICRO_AREA = "24900"
GREENWOOD_SC_MICRO_AREA = "24940"
GRENADA_MS_MICRO_AREA = "24980"
GUAYAMA_PR_METRO_AREA = "25020"
GULFPORT_BILOXI_MS_METRO_AREA = "25060"
GUYMON_OK_MICRO_AREA = "25100"
HAGERSTOWN_MARTINSBURG_MD_WV_METRO_AREA = "25180"
HAILEY_ID_MICRO_AREA = "25200"
HAMMOND_LA_METRO_AREA = "25220"
HANFORD_CORCORAN_CA_METRO_AREA = "25260"
HANNIBAL_MO_MICRO_AREA = "25300"
HARRISBURG_CARLISLE_PA_METRO_AREA = "25420"
HARRISON_AR_MICRO_AREA = "25460"
HARRISONBURG_VA_METRO_AREA = "25500"
HARTFORD_EAST_HARTFORD_MIDDLETOWN_CT_METRO_AREA = "25540"
HASTINGS_NE_MICRO_AREA = "25580"
HATTIESBURG_MS_METRO_AREA = "25620"
HAYS_KS_MICRO_AREA = "25700"
HEBER_UT_MICRO_AREA = "25720"
HELENA_MT_MICRO_AREA = "25740"
HELENA_WEST_HELENA_AR_MICRO_AREA = "25760"
HENDERSON_NC_MICRO_AREA = "25780"
HEREFORD_TX_MICRO_AREA = "25820"
HERMISTON_PENDLETON_OR_MICRO_AREA = "25840"
HICKORY_LENOIR_MORGANTON_NC_METRO_AREA = "25860"
HILLSDALE_MI_MICRO_AREA = "25880"
HILO_HI_MICRO_AREA = "25900"
HILTON_HEAD_ISLAND_BLUFFTON_SC_METRO_AREA = "25940"
HINESVILLE_GA_METRO_AREA = "25980"
HOBBS_NM_MICRO_AREA = "26020"
HOLLAND_MI_MICRO_AREA = "26090"
HOMOSASSA_SPRINGS_FL_METRO_AREA = "26140"
HOOD_RIVER_OR_MICRO_AREA = "26220"
HOPE_AR_MICRO_AREA = "26260"
HOT_SPRINGS_AR_METRO_AREA = "26300"
HOUGHTON_MI_MICRO_AREA = "26340"
HOUMA_THIBODAUX_LA_METRO_AREA = "26380"
HOUSTON_THE_WOODLANDS_SUGAR_LAND_TX_METRO_AREA = "26420"
HUDSON_NY_MICRO_AREA = "26460"
HUNTINGDON_PA_MICRO_AREA = "26500"
HUNTINGTON_IN_MICRO_AREA = "26540"
HUNTINGTON_ASHLAND_WV_KY_OH_METRO_AREA = "26580"
HUNTSVILLE_AL_METRO_AREA = "26620"
HUNTSVILLE_TX_MICRO_AREA = "26660"
HURON_SD_MICRO_AREA = "26700"
HUTCHINSON_KS_MICRO_AREA = "26740"
HUTCHINSON_MN_MICRO_AREA = "26780"
IDAHO_FALLS_ID_METRO_AREA = "26820"
INDIANA_PA_MICRO_AREA = "26860"
INDIANAPOLIS_CARMEL_ANDERSON_IN_METRO_AREA = "26900"
INDIANOLA_MS_MICRO_AREA = "26940"
IOWA_CITY_IA_METRO_AREA = "26980"
IRON_MOUNTAIN_MI_WI_MICRO_AREA = "27020"
ITHACA_NY_METRO_AREA = "27060"
JACKSON_MI_METRO_AREA = "27100"
JACKSON_MS_METRO_AREA = "27140"
JACKSON_OH_MICRO_AREA = "27160"
JACKSON_TN_METRO_AREA = "27180"
JACKSON_WY_ID_MICRO_AREA = "27220"
JACKSONVILLE_FL_METRO_AREA = "27260"
JACKSONVILLE_IL_MICRO_AREA = "27300"
JACKSONVILLE_NC_METRO_AREA = "27340"
JACKSONVILLE_TX_MICRO_AREA = "27380"
JAMESTOWN_ND_MICRO_AREA = "27420"
JAMESTOWN_DUNKIRK_FREDONIA_NY_MICRO_AREA = "27460"
JANESVILLE_BELOIT_WI_METRO_AREA = "27500"
JASPER_AL_MICRO_AREA = "27530"
JASPER_IN_MICRO_AREA = "27540"
JAYUYA_PR_MICRO_AREA = "27580"
JEFFERSON_CITY_MO_METRO_AREA = "27620"
JEFFERSON_GA_MICRO_AREA = "27600"
JENNINGS_LA_MICRO_AREA = "27660"
JESUP_GA_MICRO_AREA = "27700"
JOHNSON_CITY_TN_METRO_AREA = "27740"
JOHNSTOWN_PA_METRO_AREA = "27780"
JONESBORO_AR_METRO_AREA = "27860"
JOPLIN_MO_METRO_AREA = "27900"
JUNEAU_AK_MICRO_AREA = "27940"
KAHULUI_WAILUKU_LAHAINA_HI_METRO_AREA = "27980"
KALAMAZOO_PORTAGE_MI_METRO_AREA = "28020"
KALISPELL_MT_MICRO_AREA = "28060"
KANKAKEE_IL_METRO_AREA = "28100"
KANSAS_CITY_MO_KS_METRO_AREA = "28140"
KAPAA_HI_MICRO_AREA = "28180"
KEARNEY_NE_MICRO_AREA = "28260"
KEENE_NH_MICRO_AREA = "28300"
KENDALLVILLE_IN_MICRO_AREA = "28340"
KENNETT_MO_MICRO_AREA = "28380"
KENNEWICK_RICHLAND_WA_METRO_AREA = "28420"
KERRVILLE_TX_MICRO_AREA = "28500"
KETCHIKAN_AK_MICRO_AREA = "28540"
KEY_WEST_FL_MICRO_AREA = "28580"
KILL_DEVIL_HILLS_NC_MICRO_AREA = "28620"
KILLEEN_TEMPLE_TX_METRO_AREA = "28660"
KINGSPORT_BRISTOL_TN_VA_METRO_AREA = "28700"
KINGSTON_NY_METRO_AREA = "28740"
KINGSVILLE_TX_MICRO_AREA = "28780"
KINSTON_NC_MICRO_AREA = "28820"
KIRKSVILLE_MO_MICRO_AREA = "28860"
KLAMATH_FALLS_OR_MICRO_AREA = "28900"
KNOXVILLE_TN_METRO_AREA = "28940"
KOKOMO_IN_METRO_AREA = "29020"
LA_CROSSE_ONALASKA_WI_MN_METRO_AREA = "29100"
LA_GRANDE_OR_MICRO_AREA = "29260"
LAGRANGE_GA_AL_MICRO_AREA = "29300"
LACONIA_NH_MICRO_AREA = "29060"
LAFAYETTE_LA_METRO_AREA = "29180"
LAFAYETTE_WEST_LAFAYETTE_IN_METRO_AREA = "29200"
LAKE_CHARLES_LA_METRO_AREA = "29340"
LAKE_CITY_FL_MICRO_AREA = "29380"
LAKE_HAVASU_CITY_KINGMAN_AZ_METRO_AREA = "29420"
LAKELAND_WINTER_HAVEN_FL_METRO_AREA = "29460"
LAMESA_TX_MICRO_AREA = "29500"
LANCASTER_PA_METRO_AREA = "29540"
LANSING_EAST_LANSING_MI_METRO_AREA = "29620"
LARAMIE_WY_MICRO_AREA = "29660"
LAREDO_TX_METRO_AREA = "29700"
LAS_CRUCES_NM_METRO_AREA = "29740"
LAS_VEGAS_NM_MICRO_AREA = "29780"
LAS_VEGAS_HENDERSON_PARADISE_NV_METRO_AREA = "29820"
LAUREL_MS_MICRO_AREA = "29860"
LAURINBURG_NC_MICRO_AREA = "29900"
LAWRENCE_KS_METRO_AREA = "29940"
LAWRENCEBURG_TN_MICRO_AREA = "29980"
LAWTON_OK_METRO_AREA = "30020"
LEBANON_MO_MICRO_AREA = "30060"
LEBANON_NH_VT_MICRO_AREA = "30100"
LEBANON_PA_METRO_AREA = "30140"
LEVELLAND_TX_MICRO_AREA = "30220"
LEWISBURG_PA_MICRO_AREA = "30260"
LEWISBURG_TN_MICRO_AREA = "30280"
LEWISTON_ID_WA_METRO_AREA = "30300"
LEWISTON_AUBURN_ME_METRO_AREA = "30340"
LEWISTOWN_PA_MICRO_AREA = "30380"
LEXINGTON_NE_MICRO_AREA = "30420"
LEXINGTON_FAYETTE_KY_METRO_AREA = "30460"
LIBERAL_KS_MICRO_AREA = "30580"
LIMA_OH_METRO_AREA = "30620"
LINCOLN_IL_MICRO_AREA = "30660"
LINCOLN_NE_METRO_AREA = "30700"
LITTLE_ROCK_NORTH_LITTLE_ROCK_CONWAY_AR_METRO_AREA = "30780"
LOCK_HAVEN_PA_MICRO_AREA = "30820"
LOGAN_UT_ID_METRO_AREA = "30860"
LOGANSPORT_IN_MICRO_AREA = "30900"
LONDON_KY_MICRO_AREA = "30940"
LONGVIEW_TX_METRO_AREA = "30980"
LONGVIEW_WA_METRO_AREA = "31020"
LOS_ALAMOS_NM_MICRO_AREA = "31060"
LOS_ANGELES_LONG_BEACH_ANAHEIM_CA_METRO_AREA = "31080"
LOUISVILLE_JEFFERSON_COUNTY_KY_IN_METRO_AREA = "31140"
LUBBOCK_TX_METRO_AREA = "31180"
LUDINGTON_MI_MICRO_AREA = "31220"
LUFKIN_TX_MICRO_AREA = "31260"
LUMBERTON_NC_MICRO_AREA = "31300"
LYNCHBURG_VA_METRO_AREA = "31340"
MACOMB_IL_MICRO_AREA = "31380"
MACON_BIBB_COUNTY_GA_METRO_AREA = "31420"
MADERA_CA_METRO_AREA = "31460"
MADISON_IN_MICRO_AREA = "31500"
MADISON_WI_METRO_AREA = "31540"
MADISONVILLE_KY_MICRO_AREA = "31580"
MAGNOLIA_AR_MICRO_AREA = "31620"
MALONE_NY_MICRO_AREA = "31660"
MALVERN_AR_MICRO_AREA = "31680"
MANCHESTER_NASHUA_NH_METRO_AREA = "31700"
MANHATTAN_KS_METRO_AREA = "31740"
MANITOWOC_WI_MICRO_AREA = "31820"
MANKATO_MN_METRO_AREA = "31860"
MANSFIELD_OH_METRO_AREA = "31900"
MARIETTA_OH_MICRO_AREA = "31930"
MARINETTE_WI_MI_MICRO_AREA = "31940"
MARION_IN_MICRO_AREA = "31980"
MARION_NC_MICRO_AREA = "32000"
MARION_OH_MICRO_AREA = "32020"
MARQUETTE_MI_MICRO_AREA = "32100"
MARSHALL_MN_MICRO_AREA = "32140"
MARSHALL_MO_MICRO_AREA = "32180"
MARSHALLTOWN_IA_MICRO_AREA = "32260"
MARTIN_TN_MICRO_AREA = "32280"
MARTINSVILLE_VA_MICRO_AREA = "32300"
MARYVILLE_MO_MICRO_AREA = "32340"
MASON_CITY_IA_MICRO_AREA = "32380"
MAYAGUEZ_PR_METRO_AREA = "32420"
MAYFIELD_KY_MICRO_AREA = "32460"
MAYSVILLE_KY_MICRO_AREA = "32500"
MCALESTER_OK_MICRO_AREA = "32540"
MCALLEN_EDINBURG_MISSION_TX_METRO_AREA = "32580"
MCCOMB_MS_MICRO_AREA = "32620"
MCMINNVILLE_TN_MICRO_AREA = "32660"
MCPHERSON_KS_MICRO_AREA = "32700"
MEADVILLE_PA_MICRO_AREA = "32740"
MEDFORD_OR_METRO_AREA = "32780"
MEMPHIS_TN_MS_AR_METRO_AREA = "32820"
MENOMONIE_WI_MICRO_AREA = "32860"
MERCED_CA_METRO_AREA = "32900"
MERIDIAN_MS_MICRO_AREA = "32940"
MEXICO_MO_MICRO_AREA = "33020"
MIAMI_OK_MICRO_AREA = "33060"
MIAMI_FORT_LAUDERDALE_POMPANO_BEACH_FL_METRO_AREA = "33100"
MICHIGAN_CITY_LA_PORTE_IN_METRO_AREA = "33140"
MIDDLESBOROUGH_KY_MICRO_AREA = "33180"
MIDLAND_MI_METRO_AREA = "33220"
MIDLAND_TX_METRO_AREA = "33260"
MILLEDGEVILLE_GA_MICRO_AREA = "33300"
MILWAUKEE_WAUKESHA_WI_METRO_AREA = "33340"
MINDEN_LA_MICRO_AREA = "33380"
MINERAL_WELLS_TX_MICRO_AREA = "33420"
MINNEAPOLIS_ST_PAUL_BLOOMINGTON_MN_WI_METRO_AREA = "33460"
MINOT_ND_MICRO_AREA = "33500"
MISSOULA_MT_METRO_AREA = "33540"
MITCHELL_SD_MICRO_AREA = "33580"
MOBERLY_MO_MICRO_AREA = "33620"
MOBILE_AL_METRO_AREA = "33660"
MODESTO_CA_METRO_AREA = "33700"
MONROE_LA_METRO_AREA = "33740"
MONROE_MI_METRO_AREA = "33780"
MONTGOMERY_AL_METRO_AREA = "33860"
MONTROSE_CO_MICRO_AREA = "33940"
MOREHEAD_CITY_NC_MICRO_AREA = "33980"
MORGAN_CITY_LA_MICRO_AREA = "34020"
MORGANTOWN_WV_METRO_AREA = "34060"
MORRISTOWN_TN_METRO_AREA = "34100"
MOSCOW_ID_MICRO_AREA = "34140"
MOSES_LAKE_WA_MICRO_AREA = "34180"
MOULTRIE_GA_MICRO_AREA = "34220"
MOUNT_AIRY_NC_MICRO_AREA = "34340"
MOUNT_GAY_SHAMROCK_WV_MICRO_AREA = "34350"
MOUNT_PLEASANT_MI_MICRO_AREA = "34380"
MOUNT_PLEASANT_TX_MICRO_AREA = "34420"
MOUNT_STERLING_KY_MICRO_AREA = "34460"
MOUNT_VERNON_IL_MICRO_AREA = "34500"
MOUNT_VERNON_OH_MICRO_AREA = "34540"
MOUNT_VERNON_ANACORTES_WA_METRO_AREA = "34580"
MOUNTAIN_HOME_AR_MICRO_AREA = "34260"
MOUNTAIN_HOME_ID_MICRO_AREA = "34300"
MUNCIE_IN_METRO_AREA = "34620"
MURRAY_KY_MICRO_AREA = "34660"
MUSCATINE_IA_MICRO_AREA = "34700"
MUSKEGON_MI_METRO_AREA = "34740"
MUSKOGEE_OK_MICRO_AREA = "34780"
MYRTLE_BEACH_CONWAY_NORTH_MYRTLE_BEACH_SC_NC_METRO_AREA = "34820"
NACOGDOCHES_TX_MICRO_AREA = "34860"
NAPA_CA_METRO_AREA = "34900"
NAPLES_MARCO_ISLAND_FL_METRO_AREA = "34940"
NASHVILLE_DAVIDSON_MURFREESBORO_FRANKLIN_TN_METRO_AREA = "34980"
NATCHEZ_MS_LA_MICRO_AREA = "35020"
NATCHITOCHES_LA_MICRO_AREA = "35060"
NEW_BERN_NC_METRO_AREA = "35100"
NEW_CASTLE_IN_MICRO_AREA = "35220"
NEW_CASTLE_PA_MICRO_AREA = "35260"
NEW_HAVEN_MILFORD_CT_METRO_AREA = "35300"
NEW_ORLEANS_METAIRIE_LA_METRO_AREA = "35380"
NEW_PHILADELPHIA_DOVER_OH_MICRO_AREA = "35420"
NEW_ULM_MN_MICRO_AREA = "35580"
NEW_YORK_NEWARK_JERSEY_CITY_NY_NJ_PA_METRO_AREA = "35620"
NEWBERRY_SC_MICRO_AREA = "35140"
NEWPORT_OR_MICRO_AREA = "35440"
NEWPORT_TN_MICRO_AREA = "35460"
NILES_MI_METRO_AREA = "35660"
NOGALES_AZ_MICRO_AREA = "35700"
NORFOLK_NE_MICRO_AREA = "35740"
NORTH_PLATTE_NE_MICRO_AREA = "35820"
NORTH_PORT_SARASOTA_BRADENTON_FL_METRO_AREA = "35840"
NORTH_VERNON_IN_MICRO_AREA = "35860"
NORTH_WILKESBORO_NC_MICRO_AREA = "35900"
NORWALK_OH_MICRO_AREA = "35940"
NORWICH_NEW_LONDON_CT_METRO_AREA = "35980"
OAK_HARBOR_WA_MICRO_AREA = "36020"
OCALA_FL_METRO_AREA = "36100"
OCEAN_CITY_NJ_METRO_AREA = "36140"
ODESSA_TX_METRO_AREA = "36220"
OGDEN_CLEARFIELD_UT_METRO_AREA = "36260"
OGDENSBURG_MASSENA_NY_MICRO_AREA = "36300"
OIL_CITY_PA_MICRO_AREA = "36340"
OKEECHOBEE_FL_MICRO_AREA = "36380"
OKLAHOMA_CITY_OK_METRO_AREA = "36420"
OLEAN_NY_MICRO_AREA = "36460"
OLYMPIA_LACEY_TUMWATER_WA_METRO_AREA = "36500"
OMAHA_COUNCIL_BLUFFS_NE_IA_METRO_AREA = "36540"
ONEONTA_NY_MICRO_AREA = "36580"
ONTARIO_OR_ID_MICRO_AREA = "36620"
OPELOUSAS_LA_MICRO_AREA = "36660"
ORANGEBURG_SC_MICRO_AREA = "36700"
ORLANDO_KISSIMMEE_SANFORD_FL_METRO_AREA = "36740"
OSHKOSH_NEENAH_WI_METRO_AREA = "36780"
OSKALOOSA_IA_MICRO_AREA = "36820"
OTHELLO_WA_MICRO_AREA = "36830"
OTTAWA_IL_MICRO_AREA = "36837"
OTTAWA_KS_MICRO_AREA = "36840"
OTTUMWA_IA_MICRO_AREA = "36900"
OWATONNA_MN_MICRO_AREA = "36940"
OWENSBORO_KY_METRO_AREA = "36980"
OXFORD_MS_MICRO_AREA = "37060"
OXNARD_THOUSAND_OAKS_VENTURA_CA_METRO_AREA = "37100"
OZARK_AL_MICRO_AREA = "37120"
PADUCAH_KY_IL_MICRO_AREA = "37140"
PAHRUMP_NV_MICRO_AREA = "37220"
PALATKA_FL_MICRO_AREA = "37260"
PALESTINE_TX_MICRO_AREA = "37300"
PALM_BAY_MELBOURNE_TITUSVILLE_FL_METRO_AREA = "37340"
PAMPA_TX_MICRO_AREA = "37420"
PANAMA_CITY_FL_METRO_AREA = "37460"
PARAGOULD_AR_MICRO_AREA = "37500"
PARIS_TN_MICRO_AREA = "37540"
PARIS_TX_MICRO_AREA = "37580"
PARKERSBURG_VIENNA_WV_METRO_AREA = "37620"
PARSONS_KS_MICRO_AREA = "37660"
PAYSON_AZ_MICRO_AREA = "37740"
PEARSALL_TX_MICRO_AREA = "37770"
PECOS_TX_MICRO_AREA = "37780"
PELLA_IA_MICRO_AREA = "37800"
PENSACOLA_FERRY_PASS_BRENT_FL_METRO_AREA = "37860"
PEORIA_IL_METRO_AREA = "37900"
PERU_IN_MICRO_AREA = "37940"
PHILADELPHIA_CAMDEN_WILMINGTON_PA_NJ_DE_MD_METRO_AREA = "37980"
PHOENIX_MESA_CHANDLER_AZ_METRO_AREA = "38060"
PICAYUNE_MS_MICRO_AREA = "38100"
PIERRE_SD_MICRO_AREA = "38180"
PINE_BLUFF_AR_METRO_AREA = "38220"
PINEHURST_SOUTHERN_PINES_NC_MICRO_AREA = "38240"
PITTSBURG_KS_MICRO_AREA = "38260"
PITTSBURGH_PA_METRO_AREA = "38300"
PITTSFIELD_MA_METRO_AREA = "38340"
PLAINVIEW_TX_MICRO_AREA = "38380"
PLATTEVILLE_WI_MICRO_AREA = "38420"
PLATTSBURGH_NY_MICRO_AREA = "38460"
PLYMOUTH_IN_MICRO_AREA = "38500"
POCATELLO_ID_METRO_AREA = "38540"
POINT_PLEASANT_WV_OH_MICRO_AREA = "38580"
PONCA_CITY_OK_MICRO_AREA = "38620"
PONCE_PR_METRO_AREA = "38660"
PONTIAC_IL_MICRO_AREA = "38700"
POPLAR_BLUFF_MO_MICRO_AREA = "38740"
PORT_ANGELES_WA_MICRO_AREA = "38820"
PORT_LAVACA_TX_MICRO_AREA = "38920"
PORT_ST_LUCIE_FL_METRO_AREA = "38940"
PORTALES_NM_MICRO_AREA = "38780"
PORTLAND_SOUTH_PORTLAND_ME_METRO_AREA = "38860"
PORTLAND_VANCOUVER_HILLSBORO_OR_WA_METRO_AREA = "38900"
PORTSMOUTH_OH_MICRO_AREA = "39020"
POTTSVILLE_PA_MICRO_AREA = "39060"
POUGHKEEPSIE_NEWBURGH_MIDDLETOWN_NY_METRO_AREA = "39100"
PRESCOTT_VALLEY_PRESCOTT_AZ_METRO_AREA = "39150"
PRICE_UT_MICRO_AREA = "39220"
PRINEVILLE_OR_MICRO_AREA = "39260"
PROVIDENCE_WARWICK_RI_MA_METRO_AREA = "39300"
PROVO_OREM_UT_METRO_AREA = "39340"
PUEBLO_CO_METRO_AREA = "39380"
PULLMAN_WA_MICRO_AREA = "39420"
PUNTA_GORDA_FL_METRO_AREA = "39460"
QUINCY_IL_MO_MICRO_AREA = "39500"
RACINE_WI_METRO_AREA = "39540"
RALEIGH_CARY_NC_METRO_AREA = "39580"
RAPID_CITY_SD_METRO_AREA = "39660"
RAYMONDVILLE_TX_MICRO_AREA = "39700"
READING_PA_METRO_AREA = "39740"
RED_BLUFF_CA_MICRO_AREA = "39780"
RED_WING_MN_MICRO_AREA = "39860"
REDDING_CA_METRO_AREA = "39820"
RENO_NV_METRO_AREA = "39900"
REXBURG_ID_MICRO_AREA = "39940"
RICHMOND_IN_MICRO_AREA = "39980"
RICHMOND_VA_METRO_AREA = "40060"
RICHMOND_BEREA_KY_MICRO_AREA = "40080"
RIO_GRANDE_CITY_ROMA_TX_MICRO_AREA = "40100"
RIVERSIDE_SAN_BERNARDINO_ONTARIO_CA_METRO_AREA = "40140"
RIVERTON_WY_MICRO_AREA = "40180"
ROANOKE_RAPIDS_NC_MICRO_AREA = "40260"
ROANOKE_VA_METRO_AREA = "40220"
ROCHELLE_IL_MICRO_AREA = "40300"
ROCHESTER_MN_METRO_AREA = "40340"
ROCHESTER_NY_METRO_AREA = "40380"
ROCK_SPRINGS_WY_MICRO_AREA = "40540"
ROCKFORD_IL_METRO_AREA = "40420"
ROCKINGHAM_NC_MICRO_AREA = "40460"
ROCKPORT_TX_MICRO_AREA = "40530"
ROCKY_MOUNT_NC_METRO_AREA = "40580"
ROLLA_MO_MICRO_AREA = "40620"
ROME_GA_METRO_AREA = "40660"
ROSEBURG_OR_MICRO_AREA = "40700"
ROSWELL_NM_MICRO_AREA = "40740"
RUIDOSO_NM_MICRO_AREA = "40760"
RUSSELLVILLE_AR_MICRO_AREA = "40780"
RUSTON_LA_MICRO_AREA = "40820"
RUTLAND_VT_MICRO_AREA = "40860"
SACRAMENTO_ROSEVILLE_FOLSOM_CA_METRO_AREA = "40900"
SAFFORD_AZ_MICRO_AREA = "40940"
SAGINAW_MI_METRO_AREA = "40980"
SALEM_OH_MICRO_AREA = "41400"
SALEM_OR_METRO_AREA = "41420"
SALINA_KS_MICRO_AREA = "41460"
SALINAS_CA_METRO_AREA = "41500"
SALISBURY_MD_DE_METRO_AREA = "41540"
SALT_LAKE_CITY_UT_METRO_AREA = "41620"
SAN_ANGELO_TX_METRO_AREA = "41660"
SAN_ANTONIO_NEW_BRAUNFELS_TX_METRO_AREA = "41700"
SAN_DIEGO_CHULA_VISTA_CARLSBAD_CA_METRO_AREA = "41740"
SAN_FRANCISCO_OAKLAND_BERKELEY_CA_METRO_AREA = "41860"
SAN_GERMAN_PR_METRO_AREA = "41900"
SAN_JOSE_SUNNYVALE_SANTA_CLARA_CA_METRO_AREA = "41940"
SAN_JUAN_BAYAMON_CAGUAS_PR_METRO_AREA = "41980"
SAN_LUIS_OBISPO_PASO_ROBLES_CA_METRO_AREA = "42020"
SANDPOINT_ID_MICRO_AREA = "41760"
SANDUSKY_OH_MICRO_AREA = "41780"
SANFORD_NC_MICRO_AREA = "41820"
SANTA_CRUZ_WATSONVILLE_CA_METRO_AREA = "42100"
SANTA_FE_NM_METRO_AREA = "42140"
SANTA_ISABEL_PR_MICRO_AREA = "42180"
SANTA_MARIA_SANTA_BARBARA_CA_METRO_AREA = "42200"
SANTA_ROSA_PETALUMA_CA_METRO_AREA = "42220"
SAULT_STE_MARIE_MI_MICRO_AREA = "42300"
SAVANNAH_GA_METRO_AREA = "42340"
SAYRE_PA_MICRO_AREA = "42380"
SCOTTSBLUFF_NE_MICRO_AREA = "42420"
SCOTTSBORO_AL_MICRO_AREA = "42460"
SCOTTSBURG_IN_MICRO_AREA = "42500"
SCRANTON_WILKES_BARRE_PA_METRO_AREA = "42540"
SEARCY_AR_MICRO_AREA = "42620"
SEATTLE_TACOMA_BELLEVUE_WA_METRO_AREA = "42660"
SEBASTIAN_VERO_BEACH_FL_METRO_AREA = "42680"
SEBRING_AVON_PARK_FL_METRO_AREA = "42700"
SEDALIA_MO_MICRO_AREA = "42740"
SELINSGROVE_PA_MICRO_AREA = "42780"
SELMA_AL_MICRO_AREA = "42820"
SENECA_FALLS_NY_MICRO_AREA = "42900"
SENECA_SC_MICRO_AREA = "42860"
SEVIERVILLE_TN_MICRO_AREA = "42940"
SEYMOUR_IN_MICRO_AREA = "42980"
SHAWANO_WI_MICRO_AREA = "43020"
SHAWNEE_OK_MICRO_AREA = "43060"
SHEBOYGAN_WI_METRO_AREA = "43100"
SHELBY_NC_MICRO_AREA = "43140"
SHELBYVILLE_TN_MICRO_AREA = "43180"
SHELTON_WA_MICRO_AREA = "43220"
SHERIDAN_WY_MICRO_AREA = "43260"
SHERMAN_DENISON_TX_METRO_AREA = "43300"
SHOW_LOW_AZ_MICRO_AREA = "43320"
SHREVEPORT_BOSSIER_CITY_LA_METRO_AREA = "43340"
SIDNEY_OH_MICRO_AREA = "43380"
SIERRA_VISTA_DOUGLAS_AZ_METRO_AREA = "43420"
SIKESTON_MO_MICRO_AREA = "43460"
SILVER_CITY_NM_MICRO_AREA = "43500"
SIOUX_CITY_IA_NE_SD_METRO_AREA = "43580"
SIOUX_FALLS_SD_METRO_AREA = "43620"
SNYDER_TX_MICRO_AREA = "43660"
SOMERSET_KY_MICRO_AREA = "43700"
SOMERSET_PA_MICRO_AREA = "43740"
SONORA_CA_MICRO_AREA = "43760"
SOUTH_BEND_MISHAWAKA_IN_MI_METRO_AREA = "43780"
SPARTANBURG_SC_METRO_AREA = "43900"
SPEARFISH_SD_MICRO_AREA = "43940"
SPENCER_IA_MICRO_AREA = "43980"
SPIRIT_LAKE_IA_MICRO_AREA = "44020"
SPOKANE_SPOKANE_VALLEY_WA_METRO_AREA = "44060"
SPRINGFIELD_IL_METRO_AREA = "44100"
SPRINGFIELD_MA_METRO_AREA = "44140"
SPRINGFIELD_MO_METRO_AREA = "44180"
SPRINGFIELD_OH_METRO_AREA = "44220"
ST_CLOUD_MN_METRO_AREA = "41060"
ST_GEORGE_UT_METRO_AREA = "41100"
ST_JOSEPH_MO_KS_METRO_AREA = "41140"
ST_LOUIS_MO_IL_METRO_AREA = "41180"
ST_MARYS_GA_MICRO_AREA = "41220"
ST_MARYS_PA_MICRO_AREA = "41260"
STARKVILLE_MS_MICRO_AREA = "44260"
STATE_COLLEGE_PA_METRO_AREA = "44300"
STATESBORO_GA_MICRO_AREA = "44340"
STAUNTON_VA_METRO_AREA = "44420"
STEAMBOAT_SPRINGS_CO_MICRO_AREA = "44460"
STEPHENVILLE_TX_MICRO_AREA = "44500"
STERLING_CO_MICRO_AREA = "44540"
STERLING_IL_MICRO_AREA = "44580"
STEVENS_POINT_WI_MICRO_AREA = "44620"
STILLWATER_OK_MICRO_AREA = "44660"
STOCKTON_CA_METRO_AREA = "44700"
STORM_LAKE_IA_MICRO_AREA = "44740"
STURGIS_MI_MICRO_AREA = "44780"
SULPHUR_SPRINGS_TX_MICRO_AREA = "44860"
SUMMERVILLE_GA_MICRO_AREA = "44900"
SUMTER_SC_METRO_AREA = "44940"
SUNBURY_PA_MICRO_AREA = "44980"
SUSANVILLE_CA_MICRO_AREA = "45000"
SWEETWATER_TX_MICRO_AREA = "45020"
SYRACUSE_NY_METRO_AREA = "45060"
TAHLEQUAH_OK_MICRO_AREA = "45140"
TALLADEGA_SYLACAUGA_AL_MICRO_AREA = "45180"
TALLAHASSEE_FL_METRO_AREA = "45220"
TAMPA_ST_PETERSBURG_CLEARWATER_FL_METRO_AREA = "45300"
TAOS_NM_MICRO_AREA = "45340"
TAYLORVILLE_IL_MICRO_AREA = "45380"
TERRE_HAUTE_IN_METRO_AREA = "45460"
TEXARKANA_TX_AR_METRO_AREA = "45500"
THE_DALLES_OR_MICRO_AREA = "45520"
THE_VILLAGES_FL_METRO_AREA = "45540"
THOMASTON_GA_MICRO_AREA = "45580"
THOMASVILLE_GA_MICRO_AREA = "45620"
TIFFIN_OH_MICRO_AREA = "45660"
TIFTON_GA_MICRO_AREA = "45700"
TOCCOA_GA_MICRO_AREA = "45740"
TOLEDO_OH_METRO_AREA = "45780"
TOPEKA_KS_METRO_AREA = "45820"
TORRINGTON_CT_MICRO_AREA = "45860"
TRAVERSE_CITY_MI_MICRO_AREA = "45900"
TRENTON_PRINCETON_NJ_METRO_AREA = "45940"
TROY_AL_MICRO_AREA = "45980"
TRUCKEE_GRASS_VALLEY_CA_MICRO_AREA = "46020"
TUCSON_AZ_METRO_AREA = "46060"
TULLAHOMA_MANCHESTER_TN_MICRO_AREA = "46100"
TULSA_OK_METRO_AREA = "46140"
TUPELO_MS_MICRO_AREA = "46180"
TUSCALOOSA_AL_METRO_AREA = "46220"
TWIN_FALLS_ID_METRO_AREA = "46300"
TYLER_TX_METRO_AREA = "46340"
UKIAH_CA_MICRO_AREA = "46380"
UNION_CITY_TN_MICRO_AREA = "46460"
UNION_SC_MICRO_AREA = "46420"
URBAN_HONOLULU_HI_METRO_AREA = "46520"
URBANA_OH_MICRO_AREA = "46500"
UTICA_ROME_NY_METRO_AREA = "46540"
UVALDE_TX_MICRO_AREA = "46620"
VALDOSTA_GA_METRO_AREA = "46660"
VALLEJO_CA_METRO_AREA = "46700"
VAN_WERT_OH_MICRO_AREA = "46780"
VERMILLION_SD_MICRO_AREA = "46820"
VERNAL_UT_MICRO_AREA = "46860"
VERNON_TX_MICRO_AREA = "46900"
VICKSBURG_MS_MICRO_AREA = "46980"
VICTORIA_TX_METRO_AREA = "47020"
VIDALIA_GA_MICRO_AREA = "47080"
VINCENNES_IN_MICRO_AREA = "47180"
VINELAND_BRIDGETON_NJ_METRO_AREA = "47220"
VINEYARD_HAVEN_MA_MICRO_AREA = "47240"
VIRGINIA_BEACH_NORFOLK_NEWPORT_NEWS_VA_NC_METRO_AREA = "47260"
VISALIA_CA_METRO_AREA = "47300"
WABASH_IN_MICRO_AREA = "47340"
WACO_TX_METRO_AREA = "47380"
WAHPETON_ND_MN_MICRO_AREA = "47420"
WALLA_WALLA_WA_METRO_AREA = "47460"
WAPAKONETA_OH_MICRO_AREA = "47540"
WARNER_ROBINS_GA_METRO_AREA = "47580"
WARREN_PA_MICRO_AREA = "47620"
WARRENSBURG_MO_MICRO_AREA = "47660"
WARSAW_IN_MICRO_AREA = "47700"
WASHINGTON_COURT_HOUSE_OH_MICRO_AREA = "47920"
WASHINGTON_IN_MICRO_AREA = "47780"
WASHINGTON_NC_MICRO_AREA = "47820"
WASHINGTON_ARLINGTON_ALEXANDRIA_DC_VA_MD_WV_METRO_AREA = "47900"
WATERLOO_CEDAR_FALLS_IA_METRO_AREA = "47940"
WATERTOWN_SD_MICRO_AREA = "47980"
WATERTOWN_FORT_ATKINSON_WI_MICRO_AREA = "48020"
WATERTOWN_FORT_DRUM_NY_METRO_AREA = "48060"
WAUCHULA_FL_MICRO_AREA = "48100"
WAUSAU_WESTON_WI_METRO_AREA = "48140"
WAYCROSS_GA_MICRO_AREA = "48180"
WEATHERFORD_OK_MICRO_AREA = "48220"
WEIRTON_STEUBENVILLE_WV_OH_METRO_AREA = "48260"
WENATCHEE_WA_METRO_AREA = "48300"
WEST_PLAINS_MO_MICRO_AREA = "48460"
WEST_POINT_MS_MICRO_AREA = "48500"
WHEELING_WV_OH_METRO_AREA = "48540"
WHITEWATER_WI_MICRO_AREA = "48580"
WICHITA_FALLS_TX_METRO_AREA = "48660"
WICHITA_KS_METRO_AREA = "48620"
WILLIAMSPORT_PA_METRO_AREA = "48700"
WILLISTON_ND_MICRO_AREA = "48780"
WILLMAR_MN_MICRO_AREA = "48820"
WILMINGTON_NC_METRO_AREA = "48900"
WILMINGTON_OH_MICRO_AREA = "48940"
WILSON_NC_MICRO_AREA = "48980"
WINCHESTER_VA_WV_METRO_AREA = "49020"
WINFIELD_KS_MICRO_AREA = "49060"
WINNEMUCCA_NV_MICRO_AREA = "49080"
WINONA_MN_MICRO_AREA = "49100"
WINSTON_SALEM_NC_METRO_AREA = "49180"
WISCONSIN_RAPIDS_MARSHFIELD_WI_MICRO_AREA = "49220"
WOODWARD_OK_MICRO_AREA = "49260"
WOOSTER_OH_MICRO_AREA = "49300"
WORCESTER_MA_CT_METRO_AREA = "49340"
WORTHINGTON_MN_MICRO_AREA = "49380"
YAKIMA_WA_METRO_AREA = "49420"
YANKTON_SD_MICRO_AREA = "49460"
YAUCO_PR_METRO_AREA = "49500"
YORK_HANOVER_PA_METRO_AREA = "49620"
YOUNGSTOWN_WARREN_BOARDMAN_OH_PA_METRO_AREA = "49660"
YUBA_CITY_CA_METRO_AREA = "49700"
YUMA_AZ_METRO_AREA = "49740"
ZANESVILLE_OH_MICRO_AREA = "49780"
ZAPATA_TX_MICRO_AREA = "49820"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Montana."""


BEAVERHEAD = "001"
BIG_HORN = "003"
BLAINE = "005"
BROADWATER = "007"
CARBON = "009"
CARTER = "011"
CASCADE = "013"
CHOUTEAU = "015"
CUSTER = "017"
DANIELS = "019"
DAWSON = "021"
DEER_LODGE = "023"
FALLON = "025"
FERGUS = "027"
FLATHEAD = "029"
GALLATIN = "031"
GARFIELD = "033"
GLACIER = "035"
GOLDEN_VALLEY = "037"
GRANITE = "039"
HILL = "041"
JEFFERSON = "043"
JUDITH_BASIN = "045"
LAKE = "047"
LEWIS_AND_CLARK = "049"
LIBERTY = "051"
LINCOLN = "053"
MADISON = "057"
MCCONE = "055"
MEAGHER = "059"
MINERAL = "061"
MISSOULA = "063"
MUSSELSHELL = "065"
PARK = "067"
PETROLEUM = "069"
PHILLIPS = "071"
PONDERA = "073"
POWDER_RIVER = "075"
POWELL = "077"
PRAIRIE = "079"
RAVALLI = "081"
RICHLAND = "083"
ROOSEVELT = "085"
ROSEBUD = "087"
SANDERS = "089"
SHERIDAN = "091"
SILVER_BOW = "093"
STILLWATER = "095"
SWEET_GRASS = "097"
TETON = "099"
TOOLE = "101"
TREASURE = "103"
VALLEY = "105"
WHEATLAND = "107"
WIBAUX = "109"
YELLOWSTONE = "111"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Alaska."""


ALEUTIANS_EAST_BOROUGH = "013"
ALEUTIANS_WEST_CENSUS_AREA = "016"
ANCHORAGE_MUNICIPALITY = "020"
BETHEL_CENSUS_AREA = "050"
BRISTOL_BAY_BOROUGH = "060"
CHUGACH_CENSUS_AREA = "063"
COPPER_RIVER_CENSUS_AREA = "066"
DENALI_BOROUGH = "068"
DILLINGHAM_CENSUS_AREA = "070"
FAIRBANKS_NORTH_STAR_BOROUGH = "090"
HAINES_BOROUGH = "100"
HOONAH_ANGOON_CENSUS_AREA = "105"
JUNEAU_CITY_AND_BOROUGH = "110"
KENAI_PENINSULA_BOROUGH = "122"
KETCHIKAN_GATEWAY_BOROUGH = "130"
KODIAK_ISLAND_BOROUGH = "150"
KUSILVAK_CENSUS_AREA = "158"
LAKE_AND_PENINSULA_BOROUGH = "164"
MATANUSKA_SUSITNA_BOROUGH = "170"
NOME_CENSUS_AREA = "180"
NORTH_SLOPE_BOROUGH = "185"
NORTHWEST_ARCTIC_BOROUGH = "188"
PETERSBURG_BOROUGH = "195"
PRINCE_OF_WALES_HYDER_CENSUS_AREA = "198"
SITKA_CITY_AND_BOROUGH = "220"
SKAGWAY_MUNICIPALITY = "230"
SOUTHEAST_FAIRBANKS_CENSUS_AREA = "240"
WRANGELL_CITY_AND_BOROUGH = "275"
YAKUTAT_CITY_AND_BOROUGH = "282"
YUKON_KOYUKUK_CENSUS_AREA = "290"



# Copyright (c) 2023 Darren Erik Vengroff
"""Combined Statistical Areas."""


ALBANY_SCHENECTADY_NY_CSA = "104"
ALBUQUERQUE_SANTA_FE_LAS_VEGAS_NM_CSA = "106"
ALTOONA_HUNTINGDON_PA_CSA = "107"
AMARILLO_PAMPA_BORGER_TX_CSA = "108"
APPLETON_OSHKOSH_NEENAH_WI_CSA = "118"
ASHEVILLE_MARION_BREVARD_NC_CSA = "120"
ATLANTA_ATHENS_CLARKE_COUNTY_SANDY_SPRINGS_GA_AL_CSA = "122"
BEND_PRINEVILLE_OR_CSA = "140"
BIRMINGHAM_HOOVER_TALLADEGA_AL_CSA = "142"
BLOOMINGTON_BEDFORD_IN_CSA = "144"
BLOOMINGTON_PONTIAC_IL_CSA = "145"
BLOOMSBURG_BERWICK_SUNBURY_PA_CSA = "146"
BOISE_CITY_MOUNTAIN_HOME_ONTARIO_ID_OR_CSA = "147"
BOSTON_WORCESTER_PROVIDENCE_MA_RI_NH_CT_CSA = "148"
BOWLING_GREEN_GLASGOW_KY_CSA = "150"
BROWNSVILLE_HARLINGEN_RAYMONDVILLE_TX_CSA = "154"
BUFFALO_CHEEKTOWAGA_OLEAN_NY_CSA = "160"
BURLINGTON_FORT_MADISON_KEOKUK_IA_IL_MO_CSA = "161"
BURLINGTON_SOUTH_BURLINGTON_BARRE_VT_CSA = "162"
CAPE_CORAL_FORT_MYERS_NAPLES_FL_CSA = "163"
CAPE_GIRARDEAU_SIKESTON_MO_IL_CSA = "164"
CEDAR_RAPIDS_IOWA_CITY_IA_CSA = "168"
CHARLESTON_HUNTINGTON_ASHLAND_WV_OH_KY_CSA = "170"
CHARLOTTE_CONCORD_NC_SC_CSA = "172"
CHATTANOOGA_CLEVELAND_DALTON_TN_GA_CSA = "174"
CHICAGO_NAPERVILLE_IL_IN_WI_CSA = "176"
CINCINNATI_WILMINGTON_MAYSVILLE_OH_KY_IN_CSA = "178"
CLEVELAND_AKRON_CANTON_OH_CSA = "184"
CLEVELAND_INDIANOLA_MS_CSA = "185"
CLOVIS_PORTALES_NM_CSA = "188"
COLUMBIA_MOBERLY_MEXICO_MO_CSA = "190"
COLUMBIA_ORANGEBURG_NEWBERRY_SC_CSA = "192"
COLUMBUS_AUBURN_OPELIKA_GA_AL_CSA = "194"
COLUMBUS_MARION_ZANESVILLE_OH_CSA = "198"
COLUMBUS_WEST_POINT_MS_CSA = "200"
CORPUS_CHRISTI_KINGSVILLE_ALICE_TX_CSA = "204"
DALLAS_FORT_WORTH_TX_OK_CSA = "206"
DAVENPORT_MOLINE_IA_IL_CSA = "209"
DAYTON_SPRINGFIELD_KETTERING_OH_CSA = "212"
DERIDDER_FORT_POLK_SOUTH_LA_CSA = "217"
DENVER_AURORA_CO_CSA = "216"
DES_MOINES_AMES_WEST_DES_MOINES_IA_CSA = "218"
DETROIT_WARREN_ANN_ARBOR_MI_CSA = "220"
DIXON_STERLING_IL_CSA = "221"
DOTHAN_OZARK_AL_CSA = "222"
EAU_CLAIRE_MENOMONIE_WI_CSA = "232"
EDWARDS_GLENWOOD_SPRINGS_CO_CSA = "233"
EL_PASO_LAS_CRUCES_TX_NM_CSA = "238"
ELMIRA_CORNING_NY_CSA = "236"
ERIE_MEADVILLE_PA_CSA = "240"
FARGO_WAHPETON_ND_MN_CSA = "244"
FAYETTEVILLE_SANFORD_LUMBERTON_NC_CSA = "246"
FORT_WAYNE_HUNTINGTON_AUBURN_IN_CSA = "258"
FRESNO_MADERA_HANFORD_CA_CSA = "260"
GAINESVILLE_LAKE_CITY_FL_CSA = "264"
GRAND_RAPIDS_KENTWOOD_MUSKEGON_MI_CSA = "266"
GREEN_BAY_SHAWANO_WI_CSA = "267"
GREENSBORO_WINSTON_SALEM_HIGH_POINT_NC_CSA = "268"
GREENVILLE_KINSTON_WASHINGTON_NC_CSA = "272"
GREENVILLE_SPARTANBURG_ANDERSON_SC_CSA = "273"
HARRISBURG_YORK_LEBANON_PA_CSA = "276"
HARRISONBURG_STAUNTON_VA_CSA = "277"
HARTFORD_EAST_HARTFORD_CT_CSA = "278"
HATTIESBURG_LAUREL_MS_CSA = "279"
HOT_SPRINGS_MALVERN_AR_CSA = "284"
HOUSTON_THE_WOODLANDS_TX_CSA = "288"
HUNTSVILLE_DECATUR_AL_CSA = "290"
IDAHO_FALLS_REXBURG_BLACKFOOT_ID_CSA = "292"
INDIANAPOLIS_CARMEL_MUNCIE_IN_CSA = "294"
ITHACA_CORTLAND_NY_CSA = "296"
JACKSON_BROWNSVILLE_TN_CSA = "297"
JACKSON_VICKSBURG_BROOKHAVEN_MS_CSA = "298"
JACKSONVILLE_ST_MARYS_PALATKA_FL_GA_CSA = "300"
JOHNSON_CITY_KINGSPORT_BRISTOL_TN_VA_CSA = "304"
JOHNSTOWN_SOMERSET_PA_CSA = "306"
JONESBORO_PARAGOULD_AR_CSA = "308"
JOPLIN_MIAMI_MO_OK_CSA = "309"
KALAMAZOO_BATTLE_CREEK_PORTAGE_MI_CSA = "310"
KANSAS_CITY_OVERLAND_PARK_KANSAS_CITY_MO_KS_CSA = "312"
KENNEWICK_RICHLAND_WALLA_WALLA_WA_CSA = "313"
KERRVILLE_FREDERICKSBURG_TX_CSA = "314"
KNOXVILLE_MORRISTOWN_SEVIERVILLE_TN_CSA = "315"
KOKOMO_PERU_IN_CSA = "316"
LAFAYETTE_OPELOUSAS_MORGAN_CITY_LA_CSA = "318"
LAFAYETTE_WEST_LAFAYETTE_FRANKFORT_IN_CSA = "320"
LAKE_CHARLES_JENNINGS_LA_CSA = "324"
LAS_VEGAS_HENDERSON_NV_CSA = "332"
LEXINGTON_FAYETTE_RICHMOND_FRANKFORT_KY_CSA = "336"
LIMA_VAN_WERT_CELINA_OH_CSA = "338"
LINCOLN_BEATRICE_NE_CSA = "339"
LITTLE_ROCK_NORTH_LITTLE_ROCK_AR_CSA = "340"
LOS_ANGELES_LONG_BEACH_CA_CSA = "348"
LOUISVILLE_JEFFERSON_COUNTY_ELIZABETHTOWN_BARDSTOWN_KY_IN_CSA = "350"
LUBBOCK_PLAINVIEW_LEVELLAND_TX_CSA = "352"
MACON_BIBB_COUNTY_WARNER_ROBINS_GA_CSA = "356"
MADISON_JANESVILLE_BELOIT_WI_CSA = "357"
MANKATO_NEW_ULM_MN_CSA = "359"
MANSFIELD_ASHLAND_BUCYRUS_OH_CSA = "360"
MARINETTE_IRON_MOUNTAIN_WI_MI_CSA = "361"
MARTIN_UNION_CITY_TN_CSA = "362"
MAYAGUEZ_SAN_GERMAN_PR_CSA = "364"
MCALLEN_EDINBURG_TX_CSA = "365"
MEDFORD_GRANTS_PASS_OR_CSA = "366"
MEMPHIS_FORREST_CITY_TN_MS_AR_CSA = "368"
MIAMI_PORT_ST_LUCIE_FORT_LAUDERDALE_FL_CSA = "370"
MIDLAND_ODESSA_TX_CSA = "372"
MILWAUKEE_RACINE_WAUKESHA_WI_CSA = "376"
MINNEAPOLIS_ST_PAUL_MN_WI_CSA = "378"
MOBILE_DAPHNE_FAIRHOPE_AL_CSA = "380"
MONROE_RUSTON_LA_CSA = "384"
MONTGOMERY_SELMA_ALEXANDER_CITY_AL_CSA = "388"
MORGANTOWN_FAIRMONT_WV_CSA = "390"
MOSES_LAKE_OTHELLO_WA_CSA = "393"
MOUNT_PLEASANT_ALMA_MI_CSA = "394"
MYRTLE_BEACH_CONWAY_SC_NC_CSA = "396"
NASHVILLE_DAVIDSON_MURFREESBORO_TN_CSA = "400"
NEW_BERN_MOREHEAD_CITY_NC_CSA = "404"
NEW_ORLEANS_METAIRIE_HAMMOND_LA_MS_CSA = "406"
NEW_YORK_NEWARK_NY_NJ_CT_PA_CSA = "408"
NORTH_PORT_SARASOTA_FL_CSA = "412"
OKLAHOMA_CITY_SHAWNEE_OK_CSA = "416"
OMAHA_COUNCIL_BLUFFS_FREMONT_NE_IA_CSA = "420"
ORLANDO_LAKELAND_DELTONA_FL_CSA = "422"
PADUCAH_MAYFIELD_KY_IL_CSA = "424"
PARKERSBURG_MARIETTA_VIENNA_WV_OH_CSA = "425"
PENSACOLA_FERRY_PASS_FL_AL_CSA = "426"
PHILADELPHIA_READING_CAMDEN_PA_NJ_DE_MD_CSA = "428"
PHOENIX_MESA_AZ_CSA = "429"
PITTSBURGH_NEW_CASTLE_WEIRTON_PA_OH_WV_CSA = "430"
PONCE_YAUCO_COAMO_PR_CSA = "434"
PORTLAND_LEWISTON_SOUTH_PORTLAND_ME_CSA = "438"
PORTLAND_VANCOUVER_SALEM_OR_WA_CSA = "440"
PUEBLO_CANON_CITY_CO_CSA = "444"
PULLMAN_MOSCOW_WA_ID_CSA = "446"
QUINCY_HANNIBAL_IL_MO_CSA = "448"
RALEIGH_DURHAM_CARY_NC_CSA = "450"
RAPID_CITY_SPEARFISH_SD_CSA = "452"
REDDING_RED_BLUFF_CA_CSA = "454"
RENO_CARSON_CITY_FERNLEY_NV_CSA = "456"
RICHMOND_CONNERSVILLE_IN_CSA = "458"
ROCHESTER_AUSTIN_MN_CSA = "462"
ROCHESTER_BATAVIA_SENECA_FALLS_NY_CSA = "464"
ROCKFORD_FREEPORT_ROCHELLE_IL_CSA = "466"
ROCKY_MOUNT_WILSON_ROANOKE_RAPIDS_NC_CSA = "468"
SACRAMENTO_ROSEVILLE_CA_CSA = "472"
SAGINAW_MIDLAND_BAY_CITY_MI_CSA = "474"
SALISBURY_CAMBRIDGE_MD_DE_CSA = "480"
SALT_LAKE_CITY_PROVO_OREM_UT_CSA = "482"
SAN_ANTONIO_NEW_BRAUNFELS_PEARSALL_TX_CSA = "484"
SAN_JOSE_SAN_FRANCISCO_OAKLAND_CA_CSA = "488"
SAN_JUAN_BAYAMON_PR_CSA = "490"
SAVANNAH_HINESVILLE_STATESBORO_GA_CSA = "496"
SCOTTSBORO_FORT_PAYNE_AL_CSA = "497"
SEATTLE_TACOMA_WA_CSA = "500"
SHREVEPORT_BOSSIER_CITY_MINDEN_LA_CSA = "508"
SOUTH_BEND_ELKHART_MISHAWAKA_IN_MI_CSA = "515"
SPENCER_SPIRIT_LAKE_IA_CSA = "517"
SPOKANE_SPOKANE_VALLEY_COEUR_DALENE_WA_ID_CSA = "518"
SPRINGFIELD_JACKSONVILLE_LINCOLN_IL_CSA = "522"
ST_LOUIS_ST_CHARLES_FARMINGTON_MO_IL_CSA = "476"
STATE_COLLEGE_DUBOIS_PA_CSA = "524"
STEAMBOAT_SPRINGS_CRAIG_CO_CSA = "525"
SYRACUSE_AUBURN_NY_CSA = "532"
TOLEDO_FINDLAY_TIFFIN_OH_CSA = "534"
TUCSON_NOGALES_AZ_CSA = "536"
TULSA_MUSKOGEE_BARTLESVILLE_OK_CSA = "538"
TUPELO_CORINTH_MS_CSA = "539"
TYLER_JACKSONVILLE_TX_CSA = "540"
VICTORIA_PORT_LAVACA_TX_CSA = "544"
VIRGINIA_BEACH_NORFOLK_VA_NC_CSA = "545"
WASHINGTON_BALTIMORE_ARLINGTON_DC_MD_VA_WV_PA_CSA = "548"
WAUSAU_STEVENS_POINT_WISCONSIN_RAPIDS_WI_CSA = "554"
WICHITA_WINFIELD_KS_CSA = "556"
WILLIAMSPORT_LOCK_HAVEN_PA_CSA = "558"
YOUNGSTOWN_WARREN_OH_PA_CSA = "566"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Oklahoma."""


ADAIR = "001"
ALFALFA = "003"
ATOKA = "005"
BEAVER = "007"
BECKHAM = "009"
BLAINE = "011"
BRYAN = "013"
CADDO = "015"
CANADIAN = "017"
CARTER = "019"
CHEROKEE = "021"
CHOCTAW = "023"
CIMARRON = "025"
CLEVELAND = "027"
COAL = "029"
COMANCHE = "031"
COTTON = "033"
CRAIG = "035"
CREEK = "037"
CUSTER = "039"
DELAWARE = "041"
DEWEY = "043"
ELLIS = "045"
GARFIELD = "047"
GARVIN = "049"
GRADY = "051"
GRANT = "053"
GREER = "055"
HARMON = "057"
HARPER = "059"
HASKELL = "061"
HUGHES = "063"
JACKSON = "065"
JEFFERSON = "067"
JOHNSTON = "069"
KAY = "071"
KINGFISHER = "073"
KIOWA = "075"
LATIMER = "077"
LE_FLORE = "079"
LINCOLN = "081"
LOGAN = "083"
LOVE = "085"
MAJOR = "093"
MARSHALL = "095"
MAYES = "097"
MCCLAIN = "087"
MCCURTAIN = "089"
MCINTOSH = "091"
MURRAY = "099"
MUSKOGEE = "101"
NOBLE = "103"
NOWATA = "105"
OKFUSKEE = "107"
OKLAHOMA = "109"
OKMULGEE = "111"
OSAGE = "113"
OTTAWA = "115"
PAWNEE = "117"
PAYNE = "119"
PITTSBURG = "121"
PONTOTOC = "123"
POTTAWATOMIE = "125"
PUSHMATAHA = "127"
ROGER_MILLS = "129"
ROGERS = "131"
SEMINOLE = "133"
SEQUOYAH = "135"
STEPHENS = "137"
TEXAS = "139"
TILLMAN = "141"
TULSA = "143"
WAGONER = "145"
WASHINGTON = "147"
WASHITA = "149"
WOODS = "151"
WOODWARD = "153"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Arizona."""


APACHE = "001"
COCHISE = "003"
COCONINO = "005"
GILA = "007"
GRAHAM = "009"
GREENLEE = "011"
LA_PAZ = "012"
MARICOPA = "013"
MOHAVE = "015"
NAVAJO = "017"
PIMA = "019"
PINAL = "021"
SANTA_CRUZ = "023"
YAVAPAI = "025"
YUMA = "027"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Arizona."""


AGUILA_CDP = "00730"
AJO_CDP = "00870"
AK_CHIN_CDP = "00940"
AK_CHIN_VILLAGE_CDP = "01090"
ALAMO_LAKE_CDP = "01170"
ALI_CHUK_CDP = "01560"
ALI_CHUKSON_CDP = "01570"
ALI_MOLINA_CDP = "01620"
ALPINE_CDP = "01920"
AMADO_CDP = "01990"
ANEGAM_CDP = "02270"
ANTARES_CDP = "02410"
ANTHEM_CDP = "02430"
APACHE_JUNCTION_CITY = "02830"
ARIVACA_CDP = "03320"
ARIVACA_JUNCTION_CDP = "03380"
ARIZONA_CITY_CDP = "03530"
ARIZONA_VILLAGE_CDP = "03915"
ARLINGTON_CDP = "04020"
ASH_FORK_CDP = "04440"
AVENUE_B_AND_C_CDP = "04710"
AVONDALE_CITY = "04720"
AVRA_VALLEY_CDP = "04880"
AZTEC_CDP = "04930"
BAGDAD_CDP = "05140"
BEAR_FLAT_CDP = "05450"
BEAVER_DAM_CDP = "05490"
BEAVER_VALLEY_CDP = "05495"
BELLEMONT_CDP = "05700"
BENSON_CITY = "05770"
BEYERVILLE_CDP = "05970"
BISBEE_CITY = "06260"
BITTER_SPRINGS_CDP = "06470"
BLACK_CANYON_CITY_CDP = "06610"
BLACKWATER_CDP = "06820"
BLUE_RIDGE_CDP = "06997"
BLUEWATER_CDP = "07025"
BOUSE_CDP = "07310"
BOWIE_CDP = "07380"
BRENDA_CDP = "07590"
BRYCE_CDP = "07915"
BUCKEYE_CITY = "07940"
BUCKSHOT_CDP = "08020"
BULLHEAD_CITY_CITY = "08220"
BURNSIDE_CDP = "08535"
BYLAS_CDP = "08710"
CACTUS_FLATS_CDP = "08920"
CACTUS_FOREST_CDP = "08990"
CAMERON_CDP = "09340"
CAMP_VERDE_TOWN = "09690"
CAMPO_BONITO_CDP = "09580"
CANE_BEDS_CDP = "09900"
CANYON_DAY_CDP = "10040"
CAREFREE_TOWN = "10180"
CARRIZO_CDP = "10320"
CASA_BLANCA_CDP = "10460"
CASA_GRANDE_CITY = "10530"
CASAS_ADOBES_CDP = "10670"
CATALINA_CDP = "11160"
CATALINA_FOOTHILLS_CDP = "11230"
CAVE_CREEK_TOWN = "11300"
CEDAR_CREEK_CDP = "11370"
CENTENNIAL_PARK_CDP = "11500"
CENTRAL_CDP = "11580"
CENTRAL_HEIGHTS_MIDLAND_CITY_CDP = "11720"
CHANDLER_CITY = "12000"
CHARCO_CDP = "12150"
CHIAWULI_TAK_CDP = "12560"
CHILCHINBITO_CDP = "12630"
CHINLE_CDP = "12770"
CHINO_VALLEY_TOWN = "12840"
CHLORIDE_CDP = "12910"
CHRISTOPHER_CREEK_CDP = "13140"
CHUICHU_CDP = "13190"
CIBECUE_CDP = "13400"
CIBOLA_CDP = "13470"
CIENEGA_SPRINGS_CDP = "13540"
CIRCLE_CITY_CDP = "13610"
CITRUS_PARK_CDP = "13820"
CLACKS_CANYON_CDP = "13850"
CLARKDALE_TOWN = "13890"
CLAY_SPRINGS_CDP = "14030"
CLAYPOOL_CDP = "13960"
CLIFTON_TOWN = "14380"
COLORADO_CITY_TOWN = "14870"
COMOBABI_CDP = "15080"
CONCHO_CDP = "15150"
CONGRESS_CDP = "15220"
COOLIDGE_CITY = "15500"
COPPER_HILL_CDP = "15600"
CORDES_LAKES_CDP = "15765"
CORNFIELDS_CDP = "15850"
CORNVILLE_CDP = "15920"
CORONA_DE_TUCSON_CDP = "16030"
COTTONWOOD_CDP = "16360"
COTTONWOOD_CITY = "16410"
COWLIC_CDP = "16830"
CROZIER_CDP = "17460"
CRYSTAL_BEACH_CDP = "17500"
CUTTER_CDP = "17810"
DATELAND_CDP = "18160"
DEER_CREEK_CDP = "18448"
DEL_MUERTO_CDP = "18490"
DENNEHOTSO_CDP = "18580"
DESERT_HILLS_CDP = "18740"
DEWEY_HUMBOLDT_TOWN = "19145"
DILKON_CDP = "19280"
DOLAN_SPRINGS_CDP = "19630"
DONEY_PARK_CDP = "19740"
DONOVAN_ESTATES_CDP = "19790"
DOUGLAS_CITY = "20050"
DRAGOON_CDP = "20330"
DREXEL_HEIGHTS_CDP = "20540"
DRIPPING_SPRINGS_CDP = "20560"
DRYSDALE_CDP = "20570"
DUDLEYVILLE_CDP = "20680"
DUNCAN_TOWN = "20750"
EAGAR_TOWN = "20960"
EAST_FORK_CDP = "21310"
EAST_GLOBE_CDP = "21410"
EAST_VERDE_ESTATES_CDP = "21545"
EHRENBERG_CDP = "21800"
EL_CAPITAN_CDP = "21900"
EL_MIRAGE_CITY = "22220"
EL_PRADO_ESTATES_CDP = "22400"
ELEPHANT_HEAD_CDP = "21980"
ELFRIDA_CDP = "22080"
ELGIN_CDP = "22150"
ELOY_CITY = "22360"
FIRST_MESA_CDP = "23512"
FLAGSTAFF_CITY = "23620"
FLORENCE_TOWN = "23760"
FLOWING_SPRINGS_CDP = "23955"
FLOWING_WELLS_CDP = "23960"
FOREST_LAKES_CDP = "24100"
FORT_APACHE_CDP = "24250"
FORT_DEFIANCE_CDP = "24460"
FORT_MOHAVE_CDP = "24895"
FORT_THOMAS_CDP = "24950"
FORT_VALLEY_CDP = "25045"
FORTUNA_FOOTHILLS_CDP = "25030"
FOUNTAIN_HILLS_TOWN = "25300"
FRANKLIN_CDP = "25650"
FREDONIA_TOWN = "25720"
FREEDOM_ACRES_CDP = "25735"
GADSDEN_CDP = "26070"
GANADO_CDP = "26210"
GERONIMO_ESTATES_CDP = "26780"
GILA_BEND_TOWN = "27050"
GILA_CROSSING_CDP = "27260"
GILBERT_TOWN = "27400"
GISELA_CDP = "27540"
GLENDALE_CITY = "27820"
GLOBE_CITY = "28030"
GOLD_CANYON_CDP = "28140"
GOLDEN_SHORES_CDP = "28190"
GOLDEN_VALLEY_CDP = "28195"
GOODYEAR_VILLAGE_CDP = "28465"
GOODYEAR_CITY = "28380"
GRAND_CANYON_VILLAGE_CDP = "28981"
GRAND_CANYON_WEST_CDP = "28985"
GREASEWOOD_CDP = "29430"
GREEN_VALLEY_CDP = "29710"
GREENEHAVEN_CDP = "29603"
GREER_CDP = "29850"
GU_OIDAK_CDP = "30550"
GUADALUPE_TOWN = "30270"
HACKBERRY_CDP = "30830"
HAIGLER_CREEK_CDP = "30840"
HAIVANA_NAKYA_CDP = "30850"
HARD_ROCK_CDP = "31182"
HAYDEN_TOWN = "32020"
HEBER_OVERGAARD_CDP = "32310"
HOLBROOK_CITY = "33280"
HONDAH_CDP = "33440"
HOTEVILLA_BACAVI_CDP = "33945"
HOUCK_CDP = "33980"
HUACHUCA_CITY_TOWN = "34120"
HUNTER_CREEK_CDP = "34700"
ICEHOUSE_CANYON_CDP = "34980"
INDIAN_WELLS_CDP = "35310"
J_SIX_RANCHETTES_CDP = "36440"
JAKES_CORNER_CDP = "36010"
JEDDITO_CDP = "36150"
JEROME_TOWN = "36290"
JOSEPH_CITY_CDP = "36430"
KACHINA_VILLAGE_CDP = "36475"
KAIBAB_CDP = "36500"
KAIBAB_ESTATES_WEST_CDP = "36535"
KAIBITO_CDP = "36640"
KAKA_CDP = "36780"
KATHERINE_CDP = "36920"
KAYENTA_CDP = "36990"
KEAMS_CANYON_CDP = "37130"
KEARNY_TOWN = "37200"
KINGMAN_CITY = "37620"
KINO_SPRINGS_CDP = "37935"
KLAGETOH_CDP = "38250"
KLEINDALE_CDP = "38290"
KO_VAYA_CDP = "38950"
KOHATK_CDP = "38530"
KOHLS_RANCH_CDP = "38600"
KOMATKE_CDP = "38655"
KYKOTSMOVI_VILLAGE_CDP = "39100"
LA_PAZ_VALLEY_CDP = "40160"
LAKE_HAVASU_CITY_CITY = "39370"
LAKE_MONTEZUMA_CDP = "39720"
LAKE_OF_THE_WOODS_CDP = "39790"
LAZY_Y_U_CDP = "40400"
LECHEE_CDP = "40415"
LEUPP_CDP = "40630"
LINDEN_CDP = "41085"
LITCHFIELD_PARK_CITY = "41330"
LITTLEFIELD_CDP = "41470"
LOW_MOUNTAIN_CDP = "42590"
LOWER_SANTAN_VILLAGE_CDP = "42460"
LUKACHUKAI_CDP = "42660"
LUPTON_CDP = "42940"
MAISH_VAYA_CDP = "43920"
MAMMOTH_TOWN = "43990"
MANY_FARMS_CDP = "44200"
MARANA_TOWN = "44270"
MARICOPA_COLONY_CDP = "44450"
MARICOPA_CITY = "44410"
MARTINEZ_LAKE_CDP = "44830"
MAYER_CDP = "45180"
MCCONNICO_CDP = "43150"
MCNARY_CDP = "43430"
MCNEAL_CDP = "43570"
MEAD_RANCH_CDP = "45275"
MEADVIEW_CDP = "45285"
MESA_CITY = "46000"
MESA_DEL_CABALLO_CDP = "46005"
MESCAL_CDP = "46070"
MESQUITE_CREEK_CDP = "46087"
MIAMI_TOWN = "46350"
MIRACLE_VALLEY_CDP = "46840"
MOCCASIN_CDP = "47190"
MOENKOPI_CDP = "47330"
MOHAVE_VALLEY_CDP = "47400"
MOJAVE_RANCH_ESTATES_CDP = "47495"
MORENCI_CDP = "47610"
MORMON_LAKE_CDP = "47680"
MORRISTOWN_CDP = "47750"
MOUNTAIN_VIEW_RANCHES_CDP = "47925"
MOUNTAINAIRE_CDP = "47820"
MUNDS_PARK_CDP = "48170"
NACO_CDP = "48310"
NAZLINI_CDP = "49010"
NELSON_CDP = "49100"
NEW_KINGMAN_BUTLER_CDP = "49270"
NEW_RIVER_CDP = "49360"
NOGALES_CITY = "49640"
NOLIC_CDP = "49710"
NORTH_FORK_CDP = "50000"
NUTRIOSO_CDP = "50340"
OAK_CREEK_CANYON_CDP = "50362"
OAK_SPRINGS_CDP = "50480"
OATMAN_CDP = "50620"
OLJATO_MONUMENT_VALLEY_CDP = "51142"
ORACLE_CDP = "51180"
ORANGE_GROVE_MOBILE_MANOR_CDP = "51465"
ORO_VALLEY_TOWN = "51600"
OXBOW_ESTATES_CDP = "51775"
PADRE_RANCHITOS_CDP = "51800"
PAGE_CITY = "51810"
PALOMINAS_CDP = "52230"
PARADISE_VALLEY_TOWN = "52930"
PARKER_STRIP_CDP = "53210"
PARKER_TOWN = "53070"
PARKS_CDP = "53350"
PATAGONIA_TOWN = "53490"
PAULDEN_CDP = "53560"
PAYSON_TOWN = "53700"
PEACH_SPRINGS_CDP = "53770"
PEEPLES_VALLEY_CDP = "53910"
PEORIA_CITY = "54050"
PERIDOT_CDP = "54190"
PHOENIX_CITY = "55000"
PICACHO_CDP = "55210"
PICTURE_ROCKS_CDP = "55300"
PIMA_TOWN = "55560"
PINAL_CDP = "55630"
PINE_CDP = "55700"
PINE_LAKE_CDP = "55845"
PINEDALE_CDP = "55840"
PINETOP_COUNTRY_CLUB_CDP = "55880"
PINETOP_LAKESIDE_TOWN = "55980"
PINION_PINES_CDP = "55983"
PINON_CDP = "56120"
PIRTLEVILLE_CDP = "56400"
PISINEMO_CDP = "56470"
POSTON_CDP = "57170"
PRESCOTT_VALLEY_TOWN = "57450"
PRESCOTT_CITY = "57380"
QUARTZSITE_TOWN = "58010"
QUEEN_CREEK_TOWN = "58150"
QUEEN_VALLEY_CDP = "58290"
RAINBOW_CITY_CDP = "58620"
RANCHO_MESA_VERDE_CDP = "58870"
RED_LAKE_CDP = "59372"
RED_MESA_CDP = "59550"
RED_ROCK_CDP_APACHE_COUNTY = "59690"
RED_ROCK_CDP_PINAL_COUNTY = "59760"
RILLITO_CDP = "59900"
RINCON_VALLEY_CDP = "60120"
RIO_RICO_CDP = "60180"
RIO_VERDE_CDP = "60250"
ROCK_HOUSE_CDP = "60770"
ROCK_POINT_CDP = "60880"
ROOSEVELT_CDP = "61300"
ROOSEVELT_ESTATES_CDP = "61302"
ROUGH_ROCK_CDP = "61370"
ROUND_ROCK_CDP = "61440"
ROUND_VALLEY_CDP = "61448"
RYE_CDP = "61690"
SACATE_VILLAGE_CDP = "61715"
SACATON_CDP = "61720"
SACATON_FLATS_VILLAGE_CDP = "61800"
SADDLEBROOKE_CDP = "61940"
SAFFORD_CITY = "62000"
SAHUARITA_TOWN = "62140"
SALOME_CDP = "62700"
SAN_CARLOS_CDP = "62910"
SAN_JOSE_CDP = "63260"
SAN_LUIS_CITY = "63470"
SAN_MANUEL_CDP = "63540"
SAN_MIGUEL_CDP = "63610"
SAN_SIMON_CDP = "63820"
SAN_TAN_VALLEY_CDP = "64210"
SANDERS_CDP = "63050"
SANTA_CRUZ_CDP = "63960"
SANTA_ROSA_CDP = "64310"
SAWMILL_CDP = "64590"
SCENIC_CDP = "64650"
SCOTTSDALE_CITY = "65000"
SEBA_DALKAI_CDP = "65167"
SECOND_MESA_CDP = "65280"
SEDONA_CITY = "65350"
SEHILI_CDP = "65400"
SELIGMAN_CDP = "65420"
SELLS_CDP = "65490"
SEVEN_MILE_CDP = "65780"
SHONGOPOVI_CDP = "66190"
SHONTO_CDP = "66260"
SHOW_LOW_CITY = "66470"
SHUMWAY_CDP = "66540"
SIERRA_VISTA_SOUTHEAST_CDP = "66845"
SIERRA_VISTA_CITY = "66820"
SIX_SHOOTER_CANYON_CDP = "67295"
SNOWFLAKE_TOWN = "67800"
SO_HI_CDP = "67920"
SOLOMON_CDP = "68010"
SOMERTON_CITY = "68080"
SONOITA_CDP = "68220"
SOUTH_KOMELIK_CDP = "68670"
SOUTH_TUCSON_CITY = "68850"
SPRING_VALLEY_CDP = "69060"
SPRINGERVILLE_TOWN = "68990"
ST_DAVID_CDP = "62280"
ST_JOHNS_CDP = "62362"
ST_JOHNS_CITY = "62350"
ST_MICHAELS_CDP = "62420"
STANFIELD_CDP = "69130"
STAR_VALLEY_TOWN = "69480"
STEAMBOAT_CDP = "69585"
STOTONIC_VILLAGE_CDP = "69872"
STRAWBERRY_CDP = "70040"
SUMMERHAVEN_CDP = "70175"
SUMMIT_CDP = "70240"
SUN_CITY_CDP = "70320"
SUN_CITY_WEST_CDP = "70355"
SUN_LAKES_CDP = "70530"
SUN_VALLEY_CDP = "71160"
SUNIZONA_CDP = "70460"
SUNSITES_CDP = "71020"
SUNWEST_CDP = "71220"
SUPAI_CDP = "71230"
SUPERIOR_TOWN = "71300"
SURPRISE_CITY = "71510"
SWEET_WATER_VILLAGE_CDP = "71642"
SWIFT_TRAIL_JUNCTION_CDP = "71650"
TACNA_CDP = "71790"
TANQUE_VERDE_CDP = "72000"
TAT_MOMOLI_CDP = "72280"
TAYLOR_TOWN = "72420"
TEEC_NOS_POS_CDP = "72560"
TEES_TOH_CDP = "72630"
TEMPE_CITY = "73000"
THATCHER_TOWN = "73420"
THEBA_CDP = "73490"
THREE_POINTS_CDP = "73700"
TIMBERLINE_FERNWOOD_CDP = "73890"
TOLANI_LAKE_CDP = "74120"
TOLLESON_CITY = "74190"
TOMBSTONE_CITY = "74400"
TONALEA_CDP = "74470"
TONOPAH_CDP = "74540"
TONTO_BASIN_CDP = "74610"
TONTO_VILLAGE_CDP = "74665"
TOP_OF_THE_WORLD_CDP = "74820"
TOPAWA_CDP = "74680"
TOPOCK_CDP = "74750"
TOYEI_CDP = "75310"
TRUXTON_CDP = "75590"
TSAILE_CDP = "75660"
TUBA_CITY_CDP = "76010"
TUBAC_CDP = "75940"
TUCSON_ESTATES_CDP = "77035"
TUCSON_MOUNTAINS_CDP = "77179"
TUCSON_CITY = "77000"
TUMACACORI_CARMEN_CDP = "77367"
TURKEY_CREEK_CDP = "77415"
TUSAYAN_TOWN = "77490"
UPPER_SANTAN_VILLAGE_CDP = "78300"
UTTING_CDP = "78400"
VAIL_CDP = "78540"
VAIVA_VO_CDP = "78680"
VALENCIA_WEST_CDP = "78760"
VALENTINE_CDP = "78820"
VALLE_CDP = "78855"
VALLE_VISTA_CDP = "78865"
VENTANA_CDP = "79590"
VERDE_VILLAGE_CDP = "79830"
VERNON_CDP = "79870"
VICKSBURG_CDP = "79940"
VILLAGE_OF_OAK_CREEK_BIG_PARK_CDP = "80095"
WAGON_WHEEL_CDP = "80380"
WAHAK_HOTRONTK_CDP = "80430"
WALL_LANE_CDP = "80790"
WALNUT_CREEK_CDP = "80825"
WASHINGTON_PARK_CDP = "81175"
WELLTON_HILLS_CDP = "81490"
WELLTON_TOWN = "81480"
WENDEN_CDP = "81550"
WET_CAMP_VILLAGE_CDP = "82060"
WHEATFIELDS_CDP = "82120"
WHETSTONE_CDP = "82156"
WHISPERING_PINES_CDP = "82270"
WHITE_HILLS_CDP = "82425"
WHITE_MOUNTAIN_LAKE_CDP = "82450"
WHITECONE_CDP = "82390"
WHITERIVER_CDP = "82530"
WHY_CDP = "82670"
WICKENBURG_TOWN = "82740"
WIDE_RUINS_CDP = "82810"
WIKIEUP_CDP = "82880"
WILHOIT_CDP = "82950"
WILLCOX_CITY = "83090"
WILLIAMS_CITY = "83160"
WILLIAMSON_CDP = "83388"
WILLOW_CANYON_CDP = "83475"
WILLOW_VALLEY_CDP = "83570"
WINDOW_ROCK_CDP = "83720"
WINKELMAN_TOWN = "83790"
WINSLOW_WEST_CDP = "83960"
WINSLOW_CITY = "83930"
WINTERSBURG_CDP = "84000"
WITTMANN_CDP = "84140"
WOODRUFF_CDP = "84350"
YARNELL_CDP = "84980"
YORK_CDP = "85260"
YOUNG_CDP = "85330"
YOUNGTOWN_TOWN = "85400"
YUCCA_CDP = "85470"
YUMA_PROVING_GROUND_CDP = "85680"
YUMA_CITY = "85540"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Nevada."""


ALAMO_CDP = "00500"
AMARGOSA_VALLEY_CDP = "01000"
AUSTIN_CDP = "03700"
BAKER_CDP = "04100"
BATTLE_MOUNTAIN_CDP = "04900"
BEATTY_CDP = "05100"
BEAVERDAM_CDP = "05125"
BENNETT_SPRINGS_CDP = "05275"
BLUE_DIAMOND_CDP = "05700"
BOULDER_CITY_CITY = "06500"
BUNKERVILLE_CDP = "08100"
CAL_NEV_ARI_CDP = "08600"
CALIENTE_CITY = "08500"
CARLIN_CITY = "08900"
CARSON_CITY = "09700"
CARTER_SPRINGS_CDP = "10200"
COLD_SPRINGS_CDP = "14090"
CRESCENT_VALLEY_CDP = "16300"
CRYSTAL_BAY_CDP = "16700"
DAYTON_CDP = "17500"
DENIO_CDP = "18500"
DOUBLE_SPRING_CDP = "19150"
DRY_VALLEY_CDP = "19800"
DYER_CDP = "20700"
EAST_VALLEY_CDP = "21520"
ELKO_CITY = "22500"
ELY_CITY = "23500"
EMPIRE_CDP = "23700"
ENTERPRISE_CDP = "23770"
EUREKA_CDP = "23900"
FALLON_STATION_CDP = "24500"
FALLON_CITY = "24100"
FERNLEY_CITY = "24900"
FISH_SPRINGS_CDP = "25000"
FORT_MCDERMITT_CDP = "25490"
GABBS_CDP = "25900"
GARDNERVILLE_CDP = "26300"
GARDNERVILLE_RANCHOS_CDP = "26500"
GENOA_CDP = "27100"
GERLACH_CDP = "27300"
GLENBROOK_CDP = "27900"
GOLCONDA_CDP = "28500"
GOLDEN_VALLEY_CDP = "28860"
GOLDFIELD_CDP = "28900"
GOODSPRINGS_CDP = "29500"
GRASS_VALLEY_CDP = "30220"
HAWTHORNE_CDP = "31300"
HENDERSON_CITY = "31900"
HIKO_CDP = "32900"
HUMBOLDT_RIVER_RANCH_CDP = "34100"
IMLAY_CDP = "34700"
INCLINE_VILLAGE_CDP = "35100"
INDIAN_HILLS_CDP = "35275"
INDIAN_SPRINGS_CDP = "35300"
JACKPOT_CDP = "36500"
JOHNSON_LANE_CDP = "37190"
KINGSBURY_CDP = "38000"
KINGSTON_CDP = "38100"
LAKERIDGE_CDP = "39100"
LAMOILLE_CDP = "39300"
LAS_VEGAS_CITY = "40000"
LAUGHLIN_CDP = "41000"
LEMMON_VALLEY_CDP = "41800"
LOGAN_CREEK_CDP = "42350"
LOVELOCK_CITY = "43000"
LUND_CDP = "43400"
MCDERMITT_CDP = "44000"
MCGILL_CDP = "44200"
MESQUITE_CITY = "46000"
MINA_CDP = "46800"
MINDEN_CDP = "47000"
MOAPA_TOWN_CDP = "47840"
MOAPA_VALLEY_CDP = "47880"
MOGUL_CDP = "48000"
MONTELLO_CDP = "48400"
MOUNT_CHARLESTON_CDP = "49310"
MOUNT_WILSON_CDP = "49425"
MOUNTAIN_CITY_CDP = "49200"
NELLIS_AFB_CDP = "50400"
NELSON_CDP = "50600"
NIXON_CDP = "51200"
NORTH_LAS_VEGAS_CITY = "51800"
OASIS_CDP = "52200"
OROVADA_CDP = "53000"
OSINO_CDP = "53200"
OWYHEE_CDP = "53600"
PAHRUMP_CDP = "53800"
PANACA_CDP = "54200"
PARADISE_CDP = "54600"
PARADISE_VALLEY_CDP = "55400"
PIOCHE_CDP = "57400"
PRESTON_CDP = "58000"
RACHEL_CDP = "58820"
RENO_CITY = "60600"
ROUND_HILL_VILLAGE_CDP = "62170"
RUHENSTROTH_CDP = "63450"
RUTH_CDP = "63800"
SANDY_VALLEY_CDP = "64600"
SCHURZ_CDP = "65400"
SEARCHLIGHT_CDP = "65600"
SILVER_CITY_CDP = "66800"
SILVER_PEAK_CDP = "67000"
SILVER_SPRINGS_CDP = "67200"
SKYLAND_CDP = "67600"
SMITH_VALLEY_CDP = "68050"
SPANISH_SPRINGS_CDP = "68350"
SPARKS_CITY = "68400"
SPRING_CREEK_CDP = "68550"
SPRING_VALLEY_CDP = "68585"
STAGECOACH_CDP = "68800"
STATELINE_CDP = "69200"
SUMMERLIN_SOUTH_CDP = "70900"
SUN_VALLEY_CDP = "71600"
SUNRISE_MANOR_CDP = "71400"
SUTCLIFFE_CDP = "71800"
TONOPAH_CDP = "73600"
TOPAZ_LAKE_CDP = "74200"
TOPAZ_RANCH_ESTATES_CDP = "74400"
UNIONVILLE_CDP = "76400"
URSINE_CDP = "77200"
VALMY_CDP = "78200"
VERDI_CDP = "79400"
VIRGINIA_CITY_CDP = "80000"
WADSWORTH_CDP = "81000"
WALKER_LAKE_CDP = "81100"
WASHOE_VALLEY_CDP = "82250"
WELLS_CITY = "83000"
WEST_WENDOVER_CITY = "83730"
WHITNEY_CDP = "83800"
WINCHESTER_CDP = "84600"
WINNEMUCCA_CITY = "84800"
YERINGTON_CITY = "85400"
ZEPHYR_COVE_CDP = "86200"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Rhode Island."""


ASHAWAY_CDP = "03520"
BRADFORD_CDP = "08020"
CAROLINA_CDP = "12340"
CENTRAL_FALLS_CITY = "14140"
CHARLESTOWN_CDP = "14320"
CHEPACHET_CDP = "14860"
CLAYVILLE_CDP = "15940"
CRANSTON_CITY = "19180"
CUMBERLAND_HILL_CDP = "20260"
EAST_PROVIDENCE_CITY = "22960"
FOSTER_CENTER_CDP = "27640"
GREENE_CDP = "31240"
GREENVILLE_CDP = "31600"
HARMONY_CDP = "33040"
HARRISVILLE_CDP = "33400"
HOPE_VALLEY_CDP = "34660"
HOPKINTON_CDP = "35200"
KINGSTON_CDP = "38980"
MELVILLE_CDP = "45010"
MISQUAMICUT_CDP = "46000"
NARRAGANSETT_PIER_CDP = "48700"
NEWPORT_EAST_CDP = "50140"
NEWPORT_CITY = "49960"
PASCOAG_CDP = "54460"
PAWTUCKET_CITY = "54640"
PROVIDENCE_CITY = "59000"
QUONOCHONTAUG_CDP = "60260"
TIVERTON_CDP = "70700"
VALLEY_FALLS_CDP = "72500"
WAKEFIELD_PEACE_DALE_CDP = "73132"
WARWICK_CITY = "74300"
WATCH_HILL_CDP = "75200"
WEEKAPAUG_CDP = "75920"
WESTERLY_CDP = "76820"
WOONSOCKET_CITY = "80780"
WYOMING_CDP = "80960"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Tennessee."""


ANDERSON = "001"
BEDFORD = "003"
BENTON = "005"
BLEDSOE = "007"
BLOUNT = "009"
BRADLEY = "011"
CAMPBELL = "013"
CANNON = "015"
CARROLL = "017"
CARTER = "019"
CHEATHAM = "021"
CHESTER = "023"
CLAIBORNE = "025"
CLAY = "027"
COCKE = "029"
COFFEE = "031"
CROCKETT = "033"
CUMBERLAND = "035"
DAVIDSON = "037"
DEKALB = "041"
DECATUR = "039"
DICKSON = "043"
DYER = "045"
FAYETTE = "047"
FENTRESS = "049"
FRANKLIN = "051"
GIBSON = "053"
GILES = "055"
GRAINGER = "057"
GREENE = "059"
GRUNDY = "061"
HAMBLEN = "063"
HAMILTON = "065"
HANCOCK = "067"
HARDEMAN = "069"
HARDIN = "071"
HAWKINS = "073"
HAYWOOD = "075"
HENDERSON = "077"
HENRY = "079"
HICKMAN = "081"
HOUSTON = "083"
HUMPHREYS = "085"
JACKSON = "087"
JEFFERSON = "089"
JOHNSON = "091"
KNOX = "093"
LAKE = "095"
LAUDERDALE = "097"
LAWRENCE = "099"
LEWIS = "101"
LINCOLN = "103"
LOUDON = "105"
MACON = "111"
MADISON = "113"
MARION = "115"
MARSHALL = "117"
MAURY = "119"
MCMINN = "107"
MCNAIRY = "109"
MEIGS = "121"
MONROE = "123"
MONTGOMERY = "125"
MOORE = "127"
MORGAN = "129"
OBION = "131"
OVERTON = "133"
PERRY = "135"
PICKETT = "137"
POLK = "139"
PUTNAM = "141"
RHEA = "143"
ROANE = "145"
ROBERTSON = "147"
RUTHERFORD = "149"
SCOTT = "151"
SEQUATCHIE = "153"
SEVIER = "155"
SHELBY = "157"
SMITH = "159"
STEWART = "161"
SULLIVAN = "163"
SUMNER = "165"
TIPTON = "167"
TROUSDALE = "169"
UNICOI = "171"
UNION = "173"
VAN_BUREN = "175"
WARREN = "177"
WASHINGTON = "179"
WAYNE = "181"
WEAKLEY = "183"
WHITE = "185"
WILLIAMSON = "187"
WILSON = "189"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Vermont."""


ALBANY_VILLAGE = "00400"
ALBURGH_VILLAGE = "00850"
ALGIERS_CDP = "01035"
ARLINGTON_CDP = "01375"
ASCUTNEY_CDP = "01750"
BAKERSFIELD_CDP = "02425"
BARNET_CDP = "02800"
BARRE_CITY = "03175"
BARTON_VILLAGE = "03475"
BEECHER_FALLS_CDP = "04150"
BELLOWS_FALLS_VILLAGE = "04225"
BENNINGTON_CDP = "04750"
BENSON_CDP = "05125"
BETHEL_CDP = "05725"
BOLTON_CDP = "06475"
BOLTON_VALLEY_CDP = "06700"
BRADFORD_CDP = "07225"
BRANDON_CDP = "07675"
BRATTLEBORO_CDP = "07975"
BRISTOL_CDP = "08950"
BURLINGTON_CITY = "10675"
CABOT_CDP = "11050"
CAMBRIDGE_VILLAGE = "11425"
CANAAN_CDP = "11725"
CASTLETON_CDP = "11875"
CASTLETON_FOUR_CORNERS_CDP = "12062"
CAVENDISH_CDP = "12175"
CHELSEA_CDP = "13450"
CHESTER_CDP = "13600"
CHIMNEY_HILL_CDP = "13860"
CHITTENDEN_CDP = "14275"
CONCORD_CDP = "15175"
COVENTRY_CDP = "16075"
DANBY_CDP = "16750"
DANVILLE_CDP = "17050"
DERBY_CENTER_VILLAGE = "17425"
DERBY_LINE_VILLAGE = "17500"
DORSET_CDP = "17650"
EAST_BARRE_CDP = "19075"
EAST_BURKE_CDP = "19600"
EAST_CHARLOTTE_CDP = "19975"
EAST_DORSET_CDP = "20350"
EAST_MIDDLEBURY_CDP = "21700"
EAST_MONTPELIER_CDP = "21850"
EAST_POULTNEY_CDP = "22300"
ENOSBURG_FALLS_VILLAGE = "24025"
ESSEX_JUNCTION_VILLAGE = "24400"
FAIR_HAVEN_CDP = "25450"
FAIRFAX_CDP = "24850"
FAIRLEE_CDP = "25600"
GILMAN_CDP = "27925"
GLOVER_CDP = "28000"
GRAFTON_CDP = "28825"
GRANITEVILLE_CDP = "29425"
GREENSBORO_BEND_CDP = "30325"
GREENSBORO_CDP = "30100"
GROTON_CDP = "30475"
HANKSVILLE_CDP = "31600"
HARDWICK_CDP = "31750"
HARMONYVILLE_CDP = "32050"
HARTFORD_VILLAGE_CDP = "32205"
HARTLAND_CDP = "32350"
HIGHGATE_CENTER_CDP = "33175"
HIGHGATE_SPRINGS_CDP = "33325"
HINESBURG_CDP = "33400"
HUNTINGTON_CDP = "34525"
HUNTINGTON_CENTER_CDP = "34675"
HYDE_PARK_VILLAGE = "34975"
IRASBURG_CDP = "35500"
ISLAND_POND_CDP = "35725"
JACKSONVILLE_VILLAGE = "36025"
JAMAICA_CDP = "36100"
JEFFERSONVILLE_VILLAGE = "36475"
JERICHO_VILLAGE = "36625"
JOHNSON_VILLAGE = "37000"
KILLINGTON_VILLAGE_CDP = "37750"
LINCOLN_CDP = "40000"
LONDONDERRY_CDP = "40150"
LOWELL_CDP = "40450"
LUDLOW_VILLAGE = "41200"
LUNENBURG_CDP = "41350"
LYNDON_CDP = "41650"
LYNDON_CENTER_CDP = "41800"
LYNDONVILLE_VILLAGE = "41950"
MANCHESTER_CENTER_CDP = "42925"
MANCHESTER_VILLAGE = "42700"
MARSHFIELD_VILLAGE = "43525"
MIDDLEBURY_CDP = "44275"
MIDDLETOWN_SPRINGS_CDP = "44725"
MILTON_CDP = "45175"
MONTPELIER_CITY = "46000"
MORRISVILLE_VILLAGE = "46825"
NEW_HAVEN_CDP = "48550"
NEWBURY_VILLAGE = "48100"
NEWFANE_VILLAGE = "48325"
NEWPORT_CENTER_CDP = "49000"
NEWPORT_CITY = "48850"
NORTH_BENNINGTON_VILLAGE = "49075"
NORTH_CLARENDON_CDP = "49450"
NORTH_HARTLAND_CDP = "50500"
NORTH_HYDE_PARK_CDP = "50725"
NORTH_POWNAL_CDP = "51325"
NORTH_SPRINGFIELD_CDP = "51925"
NORTH_TROY_VILLAGE = "52075"
NORTH_WESTMINSTER_CDP = "52375"
NORTHFIELD_CDP = "50200"
NORWICH_CDP = "52825"
OLD_BENNINGTON_VILLAGE = "53125"
ORLEANS_VILLAGE = "53575"
PAWLET_CDP = "54175"
PEACHAM_CDP = "54325"
PITTSFORD_CDP = "55525"
PLAINFIELD_CDP = "55750"
POULTNEY_VILLAGE = "56800"
POWNAL_CDP = "56950"
POWNAL_CENTER_CDP = "57100"
PROCTOR_CDP = "57246"
PROCTORSVILLE_CDP = "57400"
PUTNEY_CDP = "57625"
QUECHEE_CDP = "57775"
RANDOLPH_CDP = "58000"
READSBORO_CDP = "58525"
RICHFORD_CDP = "59050"
RICHMOND_CDP = "59200"
ROCHESTER_CDP = "60025"
RUTLAND_CITY = "61225"
SAXTONS_RIVER_VILLAGE = "62950"
SHEFFIELD_CDP = "64000"
SHELBURNE_CDP = "64225"
SOUTH_BARRE_CDP = "66025"
SOUTH_BURLINGTON_CITY = "66175"
SOUTH_HERO_CDP = "66925"
SOUTH_LINCOLN_CDP = "67150"
SOUTH_LONDONDERRY_CDP = "67225"
SOUTH_ROYALTON_CDP = "68050"
SOUTH_SHAFTSBURY_CDP = "68200"
SOUTH_WOODSTOCK_CDP = "69250"
SPRINGFIELD_CDP = "69475"
ST_ALBANS_CITY = "61675"
ST_GEORGE_CDP = "62046"
ST_JOHNSBURY_CDP = "62125"
STAMFORD_CDP = "69700"
STOWE_CDP = "70450"
STRATTON_MOUNTAIN_CDP = "70825"
SUTTON_CDP = "71500"
SWANTON_VILLAGE = "71650"
TOWNSHEND_CDP = "73225"
TROY_CDP = "73450"
UNDERHILL_CENTER_CDP = "74050"
UNDERHILL_FLATS_CDP = "74125"
VERGENNES_CITY = "74650"
WAITSFIELD_CDP = "75250"
WALLINGFORD_CDP = "75850"
WARDSBORO_CDP = "76150"
WATERBURY_CDP = "76900"
WATERBURY_CENTER_CDP = "77050"
WEBSTERVILLE_CDP = "77800"
WELLS_CDP = "77875"
WELLS_RIVER_VILLAGE = "78025"
WEST_BRATTLEBORO_CDP = "78850"
WEST_BURKE_VILLAGE = "79150"
WEST_CHARLOTTE_CDP = "79335"
WEST_DUMMERSTON_CDP = "79750"
WEST_PAWLET_CDP = "82150"
WEST_RUTLAND_CDP = "82375"
WEST_WOODSTOCK_CDP = "83125"
WESTFORD_CDP = "80275"
WESTMINSTER_VILLAGE = "81325"
WESTON_CDP = "81925"
WHITE_RIVER_JUNCTION_CDP = "83575"
WHITINGHAM_CDP = "83875"
WILDER_CDP = "84025"
WILLIAMSTOWN_CDP = "84100"
WILMINGTON_CDP = "84625"
WINDSOR_CDP = "85000"
WINOOSKI_CITY = "85150"
WOLCOTT_CDP = "85300"
WOODSTOCK_VILLAGE = "85900"
WORCESTER_CDP = "86050"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Mississippi."""


ABBEVILLE_TOWN = "00100"
ABERDEEN_CITY = "00180"
ACKERMAN_TOWN = "00300"
AGRICOLA_CDP = "00460"
ALCORN_STATE_UNIVERSITY_CDP = "00680"
ALGOMA_TOWN = "00820"
ALLIGATOR_TOWN = "00940"
AMORY_CITY = "01260"
ANGUILLA_TOWN = "01500"
ARCOLA_TOWN = "01820"
ARKABUTLA_CDP = "01940"
ARNOLD_LINE_CDP = "02060"
ARTESIA_TOWN = "02100"
ASHLAND_TOWN = "02140"
AUSTIN_CDP = "02380"
BALDWYN_CITY = "02700"
BASSFIELD_TOWN = "03580"
BATESVILLE_CITY = "03620"
BAXTERVILLE_CDP = "03940"
BAY_SPRINGS_CITY = "04060"
BAY_ST_LOUIS_CITY = "03980"
BEAUMONT_TOWN = "04500"
BEAUREGARD_VILLAGE = "04540"
BEECHWOOD_CDP = "04705"
BELMONT_TOWN = "05100"
BELZONI_CITY = "05140"
BENNDALE_CDP = "05180"
BENOIT_TOWN = "05220"
BENTON_CDP = "05340"
BENTONIA_TOWN = "05380"
BETHLEHEM_CDP = "05780"
BEULAH_TOWN = "05820"
BIG_CREEK_VILLAGE = "06060"
BIG_POINT_CDP = "06180"
BIGGERSVILLE_CDP = "06100"
BILOXI_CITY = "06220"
BLUE_MOUNTAIN_TOWN = "07060"
BLUE_SPRINGS_VILLAGE = "07100"
BOBO_CDP = "07220"
BOGUE_CHITTO_CDP_KEMPER_AND_NESHOBA_COUNTIES = "07330"
BOGUE_CHITTO_CDP_LINCOLN_COUNTY = "07322"
BOLIVAR_CDP = "07460"
BOLTON_TOWN = "07540"
BOND_CDP = "07620"
BOONEVILLE_CITY = "07780"
BOVINA_CDP = "07900"
BOYLE_TOWN = "08180"
BRANDON_CITY = "08300"
BRAXTON_VILLAGE = "08460"
BRIDGETOWN_CDP = "08655"
BROOKHAVEN_CITY = "08820"
BROOKSVILLE_TOWN = "08980"
BRUCE_TOWN = "09180"
BUCKATUNNA_CDP = "09380"
BUDE_TOWN = "09460"
BURNSVILLE_TOWN = "09820"
BYHALIA_TOWN = "10060"
BYRAM_CITY = "10140"
CALEDONIA_TOWN = "10460"
CALHOUN_CITY_TOWN = "10580"
CANTON_CITY = "11100"
CARROLLTON_TOWN = "11580"
CARTHAGE_CITY = "11780"
CARY_TOWN = "11820"
CENTREVILLE_TOWN = "12740"
CHALYBEATE_CDP = "12780"
CHARLESTON_CITY = "12900"
CHUNKY_TOWN = "13580"
CLARA_CDP = "13700"
CLARKSDALE_CITY = "13820"
CLEARY_CDP = "14140"
CLEVELAND_CITY = "14260"
CLINTON_CITY = "14420"
CLOVERDALE_CDP = "14540"
COAHOMA_TOWN = "14580"
COFFEEVILLE_TOWN = "14740"
COLDWATER_TOWN = "14900"
COLLINS_CITY = "15140"
COLLINSVILLE_CDP = "15180"
COLUMBIA_CITY = "15340"
COLUMBUS_AFB_CDP = "15420"
COLUMBUS_CITY = "15380"
COMO_TOWN = "15500"
CONEHATTA_CDP = "15540"
CORINTH_CITY = "15700"
COURTLAND_TOWN = "15980"
CRAWFORD_TOWN = "16420"
CRENSHAW_TOWN = "16460"
CROSBY_TOWN = "16620"
CROWDER_TOWN = "16940"
CRUGER_TOWN = "16980"
CRYSTAL_SPRINGS_CITY = "17060"
DIBERVILLE_CITY = "19180"
DLO_TOWN = "19340"
DARLING_CDP = "17700"
DE_KALB_TOWN = "18340"
DE_SOTO_CDP = "18980"
DELISLE_CDP = "18420"
DECATUR_TOWN = "18180"
DELTA_CITY_CDP = "18500"
DENNIS_CDP = "18700"
DERMA_TOWN = "18940"
DIAMONDHEAD_CITY = "19100"
DODDSVILLE_TOWN = "19420"
DREW_CITY = "20020"
DUBLIN_CDP = "20220"
DUCK_HILL_TOWN = "20260"
DUMAS_TOWN = "20340"
DUNCAN_TOWN = "20380"
DUNDEE_CDP = "20420"
DURANT_CITY = "20500"
EAGLE_BEND_CDP = "20610"
EASTABUCHIE_CDP = "20740"
ECRU_TOWN = "21340"
EDEN_VILLAGE = "21420"
EDWARDS_TOWN = "21580"
ELIZABETH_CDP = "21860"
ELLIOTT_CDP = "21940"
ELLISVILLE_CITY = "22020"
ENTERPRISE_TOWN = "22580"
ESCATAWPA_CDP = "22900"
ETHEL_TOWN = "23220"
EUDORA_CDP = "23340"
EUPORA_CITY = "23420"
FALCON_TOWN = "24180"
FALKNER_TOWN = "24220"
FARMINGTON_TOWN = "24420"
FARRELL_CDP = "24460"
FAYETTE_CITY = "24500"
FERNWOOD_CDP = "24740"
FLORA_TOWN = "24940"
FLORENCE_CITY = "24980"
FLOWOOD_CITY = "25100"
FOREST_CITY = "25340"
FOXWORTH_CDP = "25740"
FRENCH_CAMP_TOWN = "26020"
FRIARS_POINT_TOWN = "26060"
FULTON_CITY = "26300"
GATTMAN_VILLAGE = "26780"
GAUTIER_CITY = "26860"
GEORGETOWN_TOWN = "26980"
GLEN_ALLAN_CDP = "27580"
GLEN_TOWN = "27540"
GLENDALE_CDP = "27620"
GLENDORA_VILLAGE = "27660"
GLOSTER_TOWN = "27820"
GLUCKSTADT_CDP = "27900"
GOLDEN_TOWN = "27940"
GOODMAN_TOWN = "28220"
GRACE_CDP = "28500"
GREENVILLE_CITY = "29180"
GREENWOOD_CITY = "29340"
GRENADA_CITY = "29460"
GULF_HILLS_CDP = "29620"
GULF_PARK_ESTATES_CDP = "29660"
GULFPORT_CITY = "29700"
GUNNISON_TOWN = "29900"
GUNTOWN_TOWN = "29940"
HAMILTON_CDP = "30220"
HARPERVILLE_CDP = "30780"
HATLEY_TOWN = "30980"
HATTIESBURG_CITY = "31020"
HAZLEHURST_CITY = "31220"
HEIDELBERG_TOWN = "31420"
HELENA_CDP = "31460"
HENDERSON_POINT_CDP = "31540"
HERMANVILLE_CDP = "31740"
HERNANDO_CITY = "31780"
HICKORY_FLAT_TOWN = "32020"
HICKORY_TOWN = "31980"
HIDE_A_WAY_LAKE_CDP = "32110"
HILLSBORO_CDP = "32460"
HOLCOMB_CDP = "32820"
HOLLANDALE_CITY = "32900"
HOLLY_SPRINGS_CITY = "33100"
HORN_LAKE_CITY = "33700"
HOUSTON_CITY = "33900"
HURLEY_CDP = "34340"
INDEPENDENCE_CDP = "34700"
INDIANOLA_CITY = "34740"
INVERNESS_TOWN = "35020"
ISOLA_TOWN = "35220"
ITTA_BENA_CITY = "35260"
IUKA_CITY = "35300"
JACINTO_CDP = "35340"
JACKSON_CITY = "36000"
JONESTOWN_TOWN = "36800"
JUMPERTOWN_TOWN = "37040"
KEARNEY_PARK_CDP = "37190"
KILMICHAEL_TOWN = "37560"
KILN_CDP = "37600"
KIRKVILLE_CDP = "37840"
KOKOMO_CDP = "38160"
KOSCIUSKO_CITY = "38320"
KOSSUTH_VILLAGE = "38360"
LAKE_TOWN = "38600"
LAKEVIEW_CDP = "38910"
LAMAR_CDP = "39000"
LAMBERT_TOWN = "39080"
LATIMER_CDP = "39520"
LAUDERDALE_CDP = "39600"
LAUREL_CITY = "39640"
LEAF_CDP = "39800"
LEAKESVILLE_TOWN = "39840"
LEARNED_TOWN = "39880"
LELAND_CITY = "40280"
LENA_TOWN = "40360"
LEXINGTON_CITY = "40600"
LIBERTY_TOWN = "40640"
LONG_BEACH_CITY = "41680"
LONGVIEW_CDP = "41960"
LOUIN_TOWN = "42200"
LOUISE_TOWN = "42240"
LOUISVILLE_CITY = "42280"
LUCEDALE_CITY = "42440"
LULA_TOWN = "42600"
LUMBERTON_CITY = "42640"
LYMAN_CDP = "42800"
LYNCHBURG_CDP = "42840"
LYON_TOWN = "42960"
MABEN_TOWN = "42980"
MACON_CITY = "44240"
MADISON_CITY = "44520"
MAGEE_CITY = "44600"
MAGNOLIA_CITY = "44680"
MANTACHIE_TOWN = "44920"
MANTEE_VILLAGE = "44960"
MARIETTA_TOWN = "45120"
MARION_TOWN = "45160"
MARKS_CITY = "45240"
MATHISTON_TOWN = "45720"
MAYERSVILLE_TOWN = "46000"
MCCOMB_CITY = "43280"
MCCOOL_TOWN = "43400"
MCLAIN_TOWN = "43840"
MEADVILLE_TOWN = "46200"
MENDENHALL_CITY = "46600"
MERIDIAN_STATION_CDP = "46680"
MERIDIAN_CITY = "46640"
MERIGOLD_TOWN = "46720"
METCALFE_TOWN = "46880"
MISSISSIPPI_STATE_CDP = "48030"
MISSISSIPPI_VALLEY_STATE_UNIVERSITY_CDP = "48120"
MIZE_TOWN = "48240"
MONTICELLO_TOWN = "48560"
MONTROSE_TOWN = "48640"
MOOREVILLE_CDP = "48720"
MOORHEAD_CITY = "48760"
MORGAN_CITY_TOWN = "48800"
MORGANTOWN_CDP = "48880"
MORTON_CITY = "49080"
MOSELLE_CDP = "49160"
MOSS_POINT_CITY = "49240"
MOUND_BAYOU_CITY = "49320"
MOUNT_OLIVE_TOWN = "49520"
MOUNT_PLEASANT_CDP = "49640"
MYRTLE_TOWN = "50280"
NATCHEZ_CITY = "50440"
NELLIEBURG_CDP = "50720"
NETTLETON_CITY = "50880"
NEW_ALBANY_CITY = "51000"
NEW_AUGUSTA_TOWN = "51040"
NEW_HAMILTON_CDP = "51240"
NEW_HEBRON_TOWN = "51360"
NEW_HOPE_CDP = "51400"
NEW_HOULKA_TOWN = "51420"
NEW_SITE_CDP = "51680"
NEWTON_CITY = "51720"
NICHOLSON_CDP = "51840"
NITTA_YUMA_CDP = "51960"
NORTH_CARROLLTON_TOWN = "52400"
NORTH_TUNICA_CDP = "52680"
NOXAPATER_TOWN = "52880"
OAK_GROVE_CDP = "53080"
OAKLAND_TOWN = "53200"
OCEAN_SPRINGS_CITY = "53520"
OKOLONA_CITY = "53680"
OLIVE_BRANCH_CITY = "54040"
OSYKA_TOWN = "54640"
OVETT_CDP = "54680"
OXFORD_CITY = "54840"
PACE_TOWN = "54920"
PACHUTA_TOWN = "54960"
PADEN_VILLAGE = "55000"
PANTHER_BURN_CDP = "55160"
PARIS_CDP = "55280"
PASCAGOULA_CITY = "55360"
PASS_CHRISTIAN_CITY = "55400"
PATTISON_CDP = "55560"
PEARL_RIVER_CDP = "55930"
PEARL_CITY = "55760"
PEARLINGTON_CDP = "55920"
PELAHATCHIE_TOWN = "56200"
PETAL_CITY = "56800"
PHEBA_CDP = "56920"
PHILADELPHIA_CITY = "56960"
PICAYUNE_CITY = "57160"
PICKENS_TOWN = "57200"
PITTSBORO_VILLAGE = "58360"
PLANTERSVILLE_TOWN = "58440"
POLKVILLE_TOWN = "58960"
PONTOTOC_CITY = "59160"
POPE_VILLAGE = "59240"
POPLARVILLE_CITY = "59480"
PORT_GIBSON_CITY = "59560"
PORTERVILLE_CDP = "59520"
POTTS_CAMP_TOWN = "59720"
PRENTISS_TOWN = "59920"
PUCKETT_VILLAGE = "60360"
PURVIS_CITY = "60480"
QUITMAN_CITY = "60720"
RALEIGH_TOWN = "60840"
RANDOLPH_CDP = "60880"
RAWLS_SPRINGS_CDP = "61080"
RAYMOND_CITY = "61160"
RED_BANKS_CDP = "61240"
REDWATER_CDP = "61400"
REDWOOD_CDP = "61440"
RENA_LARA_CDP = "61840"
RENOVA_TOWN = "61890"
RICHLAND_CITY = "62400"
RICHTON_TOWN = "62480"
RIDGELAND_CITY = "62520"
RIENZI_TOWN = "62560"
RIPLEY_CITY = "62600"
ROBINHOOD_CDP = "62900"
ROLLING_FORK_CITY = "63560"
ROSEDALE_CITY = "63720"
ROXIE_TOWN = "64080"
RULEVILLE_CITY = "64200"
RUNNELSTOWN_CDP = "64240"
SALLIS_TOWN = "64800"
SALTILLO_CITY = "64840"
SANDERSVILLE_TOWN = "64920"
SARDIS_TOWN = "65560"
SATARTIA_VILLAGE = "65680"
SAUCIER_CDP = "65720"
SCHLATER_TOWN = "66080"
SCOOBA_TOWN = "66160"
SCOTT_CDP = "66240"
SEBASTOPOL_TOWN = "66280"
SEMINARY_TOWN = "66400"
SENATOBIA_CITY = "66440"
SHANNON_TOWN = "66720"
SHARON_CDP = "66840"
SHAW_CITY = "67000"
SHELBY_CITY = "67040"
SHERMAN_TOWN = "67200"
SHUBUTA_TOWN = "67520"
SHUQUALAK_TOWN = "67640"
SIDON_TOWN = "67840"
SILVER_CITY_TOWN = "67920"
SILVER_CREEK_TOWN = "67960"
SKENE_CDP = "68200"
SLATE_SPRINGS_VILLAGE = "68320"
SLEDGE_TOWN = "68400"
SMITHVILLE_TOWN = "68720"
SNOW_LAKE_SHORES_TOWN = "68960"
SOSO_TOWN = "69160"
SOUTHAVEN_CITY = "69280"
ST_MARTIN_CDP = "64680"
STANDING_PINE_CDP = "70120"
STARKVILLE_CITY = "70240"
STATE_LINE_TOWN = "70320"
STEWART_CDP = "70640"
STONEVILLE_CDP = "70720"
STONEWALL_TOWN = "70760"
STRAYHORN_CDP = "71040"
STURGIS_TOWN = "71320"
SUMMIT_TOWN = "71480"
SUMNER_TOWN = "71520"
SUMRALL_TOWN = "71560"
SUNFLOWER_TOWN = "71600"
SYLVARENA_VILLAGE = "72040"
SYMONDS_CDP = "72080"
TAYLOR_VILLAGE = "72360"
TAYLORSVILLE_TOWN = "72400"
TCHULA_TOWN = "72440"
TERRY_TOWN = "72680"
THAXTON_TOWN = "72760"
TILLATOBA_TOWN = "73440"
TISHOMINGO_TOWN = "73720"
TOCCOPOLA_TOWN = "73760"
TOOMSUBA_CDP = "73880"
TREMONT_TOWN = "74400"
TUCKER_CDP = "74675"
TULA_CDP = "74720"
TUNICA_RESORTS_CDP = "74820"
TUNICA_TOWN = "74760"
TUPELO_CITY = "74840"
TUTWILER_TOWN = "75040"
TYLERTOWN_TOWN = "75160"
UNION_TOWN = "75360"
UNIVERSITY_CDP = "75520"
UTICA_TOWN = "75760"
VAIDEN_TOWN = "75880"
VALLEY_PARK_CDP = "76040"
VAN_VLEET_CDP = "76240"
VANCLEAVE_CDP = "76200"
VARDAMAN_TOWN = "76320"
VERONA_CITY = "76560"
VICKSBURG_CITY = "76720"
VICTORIA_CDP = "76760"
WADE_CDP = "77080"
WALLS_TOWN = "77400"
WALNUT_GROVE_TOWN = "77520"
WALNUT_TOWN = "77480"
WALTHALL_VILLAGE = "77640"
WATER_VALLEY_CITY = "78000"
WATERFORD_CDP = "77880"
WAVELAND_CITY = "78200"
WAYNESBORO_CITY = "78360"
WEBB_TOWN = "78480"
WEIR_TOWN = "78520"
WESSON_TOWN = "78640"
WEST_HATTIESBURG_CDP = "78890"
WEST_POINT_CITY = "79120"
WEST_TOWN = "78680"
WHEELER_CDP = "79280"
WHITE_OAK_CDP = "79620"
WIGGINS_CITY = "80160"
WINONA_CITY = "80760"
WINSTONVILLE_TOWN = "80800"
WINTERVILLE_CDP = "80840"
WOODLAND_VILLAGE = "81000"
WOODVILLE_TOWN = "81120"
YAZOO_CITY_CITY = "81520"
